@@ -10,7 +10,7 @@
 
 #include "config-kstars.h"
 #include "test_ekos.h"
-#include "test_ekos_helper.h"
+#include "test_ekos_capture_helper.h"
 
 #if defined(HAVE_INDI)
 
@@ -33,7 +33,7 @@ protected:
     // sequence of alignment states that are expected
     QQueue<Ekos::AlignState> expectedAlignStates;
     // sequence of telescope states that are expected
-    QQueue<ISD::Telescope::Status> expectedTelescopeStates;
+    QQueue<ISD::Mount::Status> expectedTelescopeStates;
     // sequence of capture states that are expected
     QQueue<Ekos::CaptureState> expectedCaptureStates;
 
@@ -64,12 +64,6 @@ protected slots:
      */
     bool runMountModelTool(int points, bool moveMount);
 
-    /**
-     * @brief Slew to a named target
-     * @param target target sky position
-     */
-    bool slewToTarget(SkyPoint *target);
-
     /**
      * @brief Execute a single alignment and check if the alignment target matches the given position
      * @param targetObject expected target
@@ -105,7 +99,8 @@ protected slots:
     void updateJ2000Coordinates(SkyPoint *target);
 
 private:
-    TestEkosHelper *m_test_ekos_helper;
+    // helper class
+    TestEkosCaptureHelper *m_CaptureHelper = nullptr;
 
     // test directory
     QTemporaryDir *testDir;
@@ -114,7 +109,7 @@ private:
     Ekos::AlignState m_AlignStatus { Ekos::ALIGN_IDLE };
 
     // current scope status
-    ISD::Telescope::Status m_TelescopeStatus { ISD::Telescope::MOUNT_IDLE };
+    ISD::Mount::Status m_TelescopeStatus { ISD::Mount::MOUNT_IDLE };
 
     // current capture status
     Ekos::CaptureState m_CaptureStatus { Ekos::CAPTURE_IDLE };
@@ -129,7 +124,7 @@ private:
      * @brief Slot to track the mount status
      * @param status new mount state
      */
-    void telescopeStatusChanged(ISD::Telescope::Status status);
+    void telescopeStatusChanged(ISD::Mount::Status status);
 
     /**
      * @brief Slot to track the capture status
