@@ -1,19 +1,8 @@
-/***************************************************************************
-                          ksfilereader.cpp  -  description
-                             -------------------
-    begin                : 2007-07-16
-    copyright            : (C) 2007 James B. Bowlin
-    email                : bowlin@mindspring.com
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 James B. Bowlin <bowlin@mindspring.com>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ksfilereader.h"
 
@@ -23,6 +12,8 @@
 #include "kstarsdata.h"
 #include "ksutils.h"
 
+#include <KLocalizedString>
+
 #include <QApplication>
 #include <QDebug>
 #include <QFile>
@@ -89,7 +80,7 @@ void KSFileReader::showProgress()
     //printf("%8d %8d %3d\n", m_curLine, m_totalLines, percent );
     if (percent > 100)
         percent = 100;
-    emit progressText(QString("%1 (%2%)").arg(m_label).arg(percent));
+    emit progressText(i18nc("%2 is the value, % is the percent sign", "%1 (%2%)", m_label, percent));
     //#ifdef ANDROID
     // Can cause crashes on Android
     qApp->processEvents();
