@@ -33,6 +33,7 @@ FocusDialog::FocusDialog() : QDialog(KStars::Instance())
     //initialize point to the current focus position
     Point = SkyMap::Instance()->focus();
 
+    constexpr const char* J2000EpochString = "2000.0";
     fd = new FocusDialogUI(this);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
@@ -49,34 +50,31 @@ FocusDialog::FocusDialog() : QDialog(KStars::Instance())
     okB = buttonBox->button(QDialogButtonBox::Ok);
     okB->setEnabled(false);
 
-    // When editing epoch, set JNow to false.
-    connect(fd->epochBox, &QLineEdit::editingFinished, [this]()
-    {
-        UseJNow = false;
-    });
-    fd->epochBox->setText(QString::number(KStarsData::Instance()->lt().epoch(), 'f', 3));
+    fd->epochBox->setText(J2000EpochString);
     fd->epochBox->setValidator(new QDoubleValidator(fd->epochBox));
     fd->raBox->setMinimumWidth(fd->raBox->fontMetrics().boundingRect("00h 00m 00s").width());
     fd->azBox->setMinimumWidth(fd->raBox->fontMetrics().boundingRect("00h 00m 00s").width());
 
-    fd->raBox->setDegType(false); //RA box should be HMS-style
+    fd->raBox->setUnits(dmsBox::HOURS); //RA box should be HMS-style
     fd->raBox->setFocus();        //set input focus
 
-    SkyPoint *center {nullptr};
+    const SkyPoint *center {nullptr};
     if (SkyMap::Instance()->focusObject())
-        center = dynamic_cast<SkyPoint*>(SkyMap::Instance()->focusObject());
+        center = dynamic_cast<const SkyPoint*>(SkyMap::Instance()->focusObject());
     else
-        center = SkyMap::Instance()->focusPoint();
+        center = const_cast<const SkyPoint*>(SkyMap::Instance()->focusPoint());
 
     if (center)
     {
+        // Make a copy so as to not affect the existing center point / object
+        SkyPoint centerCopy {*center};
         //center->deprecess(KStarsData::Instance()->updateNum());
-        center->catalogueCoord(KStarsData::Instance()->updateNum()->julianDay());
-        fd->raBox->setDMS(center->ra().toHMSString());
-        fd->decBox->setDMS(center->dec().toDMSString());
+        centerCopy.catalogueCoord(KStarsData::Instance()->updateNum()->julianDay());
+        fd->raBox->show(centerCopy.ra());
+        fd->decBox->show(centerCopy.dec());
 
-        fd->azBox->setDMS(center->az().toDMSString());
-        fd->altBox->setDMS(center->alt().toDMSString());
+        fd->azBox->show(centerCopy.az());
+        fd->altBox->show(centerCopy.alt());
 
         checkLineEdits();
     }
@@ -86,15 +84,13 @@ FocusDialog::FocusDialog() : QDialog(KStars::Instance())
     connect(fd->azBox, SIGNAL(textChanged(QString)), this, SLOT(checkLineEdits()));
     connect(fd->altBox, SIGNAL(textChanged(QString)), this, SLOT(checkLineEdits()));
 
-    connect(fd->J2000B, &QPushButton::clicked, [this]()
+    connect(fd->J2000B, &QPushButton::clicked, this, [&]()
     {
-        fd->epochBox->setText("2000.0");
-        UseJNow = false;
+        fd->epochBox->setText(J2000EpochString);
     });
-    connect(fd->JNowB, &QPushButton::clicked, [this]()
+    connect(fd->JNowB, &QPushButton::clicked, this, [&]()
     {
         fd->epochBox->setText(QString::number(KStarsData::Instance()->lt().epoch(), 'f', 3));
-        UseJNow = true;
     });
 
 }
@@ -103,10 +99,10 @@ void FocusDialog::checkLineEdits()
 {
     bool raOk(false), decOk(false), azOk(false), altOk(false);
 
-    fd->raBox->createDms(false, &raOk);
-    fd->decBox->createDms(true, &decOk);
-    fd->azBox->createDms(true, &azOk);
-    fd->altBox->createDms(true, &altOk);
+    fd->raBox->createDms(&raOk);
+    fd->decBox->createDms(&decOk);
+    fd->azBox->createDms(&azOk);
+    fd->altBox->createDms(&altOk);
 
     if ((raOk && decOk) || (azOk && altOk))
         okB->setEnabled(true);
@@ -117,39 +113,27 @@ void FocusDialog::checkLineEdits()
 void FocusDialog::validatePoint()
 {
     bool raOk(false), decOk(false), azOk(false), altOk(false);
-
-    //false means expressed in hours
-    dms ra(fd->raBox->createDms(false, &raOk));
-    dms dec(fd->decBox->createDms(true, &decOk));
-
     QString message;
 
-    if (raOk && decOk)
+    if (fd->fdTab->currentWidget() == fd->rdTab)
     {
-        //make sure values are in valid range
-        if (ra.Hours() < 0.0 || ra.Hours() > 24.0)
-            message = i18n("The Right Ascension value must be between 0.0 and 24.0.");
-        if (dec.Degrees() < -90.0 || dec.Degrees() > 90.0)
-            message += '\n' + i18n("The Declination value must be between -90.0 and 90.0.");
-        if (!message.isEmpty())
-        {
-            KSNotification::sorry(message, i18n("Invalid Coordinate Data"));
-            return;
-        }
+        //false means expressed in hours
+        dms ra(fd->raBox->createDms(&raOk));
+        dms dec(fd->decBox->createDms(&decOk));
 
-        // JNow
-        if (UseJNow)
-        {
-            Point->setRA(ra);
-            Point->setDec(dec);
-            //Point->deprecess(KStarsData::Instance()->updateNum());
-            Point->catalogueCoord(KStarsData::Instance()->updateNum()->julianDay());
-            // N.B. At this point (ra, dec) and (ra0, dec0) are both J2000.0 values
-            // Therefore, we precess again to get the JNow values in (ra, dec)
-            Point->apparentCoord(static_cast<long double>(J2000), KStarsData::Instance()->updateNum()->julianDay());
-        }
-        else
+        if (raOk && decOk)
         {
+            //make sure values are in valid range
+            if (ra.Hours() < 0.0 || ra.Hours() > 24.0)
+                message = i18n("The Right Ascension value must be between 0.0 and 24.0.");
+            if (dec.Degrees() < -90.0 || dec.Degrees() > 90.0)
+                message += '\n' + i18n("The Declination value must be between -90.0 and 90.0.");
+            if (!message.isEmpty())
+            {
+                KSNotification::sorry(message, i18n("Invalid Coordinate Data"));
+                return;
+            }
+
             bool ok { false };
             double epoch0   = KStarsDateTime::stringToEpoch(fd->epochBox->text(), ok);
             if (!ok)
@@ -159,21 +143,41 @@ void FocusDialog::validatePoint()
             }
             long double jd0 = KStarsDateTime::epochToJd(epoch0);
 
-            Point->setRA0(ra);
-            Point->setDec0(dec);
-            Point->apparentCoord(jd0, KStarsData::Instance()->updateNum()->julianDay());
+            // Set RA and Dec to whatever epoch we have been given (may be J2000, JNow or something completely different)
+            Point->setRA(ra);
+            Point->setDec(dec);
+
+            if (jd0 != J2000)
+            {
+                // Compute and set the J2000 coordinates of Point
+                Point->catalogueCoord(jd0);
+            }
+            else
+            {
+                Point->setRA0(ra);
+                Point->setDec0(dec);
+            }
+
+            // N.B. At this point (ra, dec) and (ra0, dec0) are both
+            // J2000.0 values Therefore, we precess again to get the
+            // values for the present draw epoch into (ra, dec)
+            Point->apparentCoord(static_cast<long double>(J2000), KStarsData::Instance()->updateNum()->julianDay());
+
+            Point->EquatorialToHorizontal(KStarsData::Instance()->lst(), KStarsData::Instance()->geo()->lat());
+            // At this point, both (RA, Dec) and (Alt, Az) should correspond to current time
+            // (RA0, Dec0) will be J2000.0 -- asimha
+
+            QDialog::accept();
+        }
+        else
+        {
+            QDialog::reject();
         }
-
-        Point->EquatorialToHorizontal(KStarsData::Instance()->lst(), KStarsData::Instance()->geo()->lat());
-        // At this point, both (RA, Dec) and (Alt, Az) should correspond to current time
-        // (RA0, Dec0) may either be J2000.0 or some other epoch -- asimha
-
-        QDialog::accept();
     }
-    else
+    else  // Az/Alt tab is active
     {
-        dms az(fd->azBox->createDms(true, &azOk));
-        dms alt(fd->altBox->createDms(true, &altOk));
+        dms az(fd->azBox->createDms(&azOk));
+        dms alt(fd->altBox->createDms(&altOk));
 
         if (azOk && altOk)
         {
