@@ -11,10 +11,10 @@
 #include "ekos/ekos.h"
 #include "ekos/guide/internalguide/starcorrespondence.h"
 #include "polaralign.h"
-#include "alignview.h"
 #include "align.h"
-#include "indi/inditelescope.h"
+#include "indi/indimount.h"
 
+class AlignView;
 class QProgressIndicator;
 class SolverUtils;
 
@@ -67,7 +67,7 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
             PAH_STAR_SELECT,
             PAH_REFRESH,
             PAH_POST_REFRESH
-        } PAHStage;
+        } Stage;
 
         // Algorithm choice in UI
         typedef enum
@@ -75,7 +75,7 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
             PLATE_SOLVE_ALGORITHM,
             MOVE_STAR_ALGORITHM,
             MOVE_STAR_UPDATE_ERR_ALGORITHM
-        } PAHRefreshAlgorithm;
+        } RefreshAlgorithm;
 
         enum CircleSolution
         {
@@ -87,18 +87,18 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         typedef enum { NORTH_HEMISPHERE, SOUTH_HEMISPHERE } HemisphereType;
 
         // Set the mount used in Align class.
-        void setCurrentTelescope(ISD::Telescope *scope)
+        void setCurrentTelescope(ISD::Mount *scope)
         {
             m_CurrentTelescope = scope;
         }
         // Sync mount slew speed and available rates from the telescope object
-        void syncMountSpeed();
+        void syncMountSpeed(const QString &speed);
         // Enable PAA if the FOV is sufficient
         void setEnabled(bool enabled);
         // Return the exposure used in the refresh phase.
         double getPAHExposureDuration() const
         {
-            return PAHExposure->value();
+            return pAHExposure->value();
         }
         // Handle updates during the refresh phase such as error estimation.
         void processPAHRefresh();
@@ -107,14 +107,15 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         // Handle both automated and manual mount rotations.
         void processMountRotation(const dms &ra, double settleDuration);
         // After solver is complete, handle PAH Stage processing
-        void processPAHStage(double orientation, double ra, double dec, double pixscale, bool eastToTheRight);
+        void processPAHStage(double orientation, double ra, double dec, double pixscale, bool eastToTheRight, short healpix,
+                             short index);
         // Return current PAH stage
-        PAHStage getPAHStage() const
+        Stage getPAHStage() const
         {
             return m_PAHStage;
         }
         // Set active stage.
-        void setPAHStage(PAHStage stage);
+        void setPAHStage(Stage stage);
         // Start the polar alignment process.
         void startPAHProcess();
         // Stops the polar alignment process.
@@ -123,34 +124,30 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         // Otherwise, we abort the operation.
         void setWCSToggled(bool result);
         // Update GUI to reflect mount status.
-        void setMountStatus(ISD::Telescope::Status newState);
+        void setMountStatus(ISD::Mount::Status newState);
         // Update the correction offset by this percentage in order to move the triangle around when clicking on
         // for example.
         void setPAHCorrectionOffsetPercentage(double dx, double dy);
         // Update the PAH refresh duration
         void setPAHRefreshDuration(double value)
         {
-            PAHExposure->setValue(value);
+            pAHExposure->setValue(value);
         }
         // Start the refresh process.
         void startPAHRefreshProcess();
         // This should be called when manual slewing is complete.
         void setPAHSlewDone();
-        // PAH Settings. PAH should be in separate class
-        QJsonObject getPAHSettings() const;
-        // Update the setting
-        void setPAHSettings(const QJsonObject &settings);
         // Return current active stage label
         QString getPAHStageString(bool translated = true) const
         {
-            return translated ? i18n(PAHStages[m_PAHStage]) : PAHStages[m_PAHStage];
+            return translated ? PAHStages[m_PAHStage].toString() : PAHStages[m_PAHStage].untranslatedText();
         }
         // Return last message
         QString getPAHMessage() const;
         // Set image data from align class
         void setImageData(const QSharedPointer<FITSData> &image);
 
-        void setPAHRefreshAlgorithm(PAHRefreshAlgorithm value);
+        void setPAHRefreshAlgorithm(RefreshAlgorithm value);
 
     protected:
         // Polar Alignment Helper slots
@@ -199,7 +196,7 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         // Report new correction vector
         void newCorrectionVector(QLineF correctionVector);
         // Report new PAH stage
-        void newPAHStage(PAHStage stage);
+        void newPAHStage(Stage stage);
         // Report new PAH message
         void newPAHMessage(const QString &message);
         // Report whether the tool is enabled or not
@@ -210,7 +207,7 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         void newFrame(const QSharedPointer<FITSView> &view);
 
     private:
-        void updateDisplay(PAHStage stage, const QString &message);
+        void updateDisplay(Stage stage, const QString &message);
         void drawArrows(double altError, double azError);
         void showUpdatedError(bool show);
         // These are only used in the plate-solve refresh scheme.
@@ -219,7 +216,7 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         void updatePlateSolveTriangle(const QSharedPointer<FITSData> &image);
 
         // Polar Alignment Helper
-        PAHStage m_PAHStage { PAH_IDLE };
+        Stage m_PAHStage { PAH_IDLE };
 
         SkyPoint targetPAH;
 
@@ -258,13 +255,13 @@ class PolarAlignmentAssistant : public QWidget, public Ui::PolarAlignmentAssista
         Align *m_AlignInstance {nullptr};
 
         // Reference to current active telescope
-        ISD::Telescope *m_CurrentTelescope { nullptr };
+        ISD::Mount *m_CurrentTelescope { nullptr };
 
         // Reference to align view
         QSharedPointer<AlignView> m_AlignView;
 
         // PAH Stage Map
-        static const QMap<PAHStage, const char *> PAHStages;
+        static const QMap<Stage, KLocalizedString> PAHStages;
 
         // Threshold to stop PAH rotation in degrees
         static constexpr uint8_t PAH_ROTATION_THRESHOLD { 5 };
