@@ -48,7 +48,11 @@ class OpticalTrainManager : public QDialog, public Ui::OpticalTrain
             FilterWheel,
             Focuser,
             Reducer,
-            LightBox
+            LightBox,
+            // Non-train specific
+            Dome,
+            Weather,
+            GPS
         } Role;
 
         void setProfile(const QSharedPointer<ProfileInfo> &profile);
@@ -130,6 +134,7 @@ class OpticalTrainManager : public QDialog, public Ui::OpticalTrain
         void refreshModel();
         void refreshTrains();
         void refreshOpticalElements();
+        void reset();
         /**
          * @brief syncDevices Sync delegates and then update model accordingly.
          */
