@@ -9,6 +9,7 @@
 #include "ui_camera.h"
 #include "ui_limits.h"
 #include "ui_calibrationoptions.h"
+#include "capturetypes.h"
 #include "customproperties.h"
 #include "rotatorsettings.h"
 #include "sequencejob.h"
@@ -48,14 +49,11 @@ class Camera : public QWidget, public Ui::Camera
     Q_OBJECT
     friend class Capture;
 public:
-    typedef enum
-    {
-        NOT_PREVIEW,
-        LOCAL_PREVIEW,
-        REMOTE_PREVIEW
-    } FilenamePreviewType;
 
+    // default constructor
     explicit Camera(int id = 0, bool standAlone = false, QWidget *parent = nullptr);
+    // constructor for standalone editor
+    explicit Camera(bool standAlone = false, QWidget *parent = nullptr);
     ~Camera();
 
     // ////////////////////////////////////////////////////////////////////
@@ -195,7 +193,7 @@ public:
      * @return pointer to job created or nullptr otherwise.
      */
     SequenceJob *createJob(SequenceJob::SequenceJobType jobtype = SequenceJob::JOBTYPE_BATCH,
-                           Camera::FilenamePreviewType filenamePreview = Camera::NOT_PREVIEW);
+                           FilenamePreviewType filenamePreview = FILENAME_NOT_PREVIEW);
 
         /**
      * @brief removeJob Remove a job sequence from the queue
@@ -203,7 +201,14 @@ public:
      *        if no row is selected, the last job shall be removed.
      * @param true if sequence is removed. False otherwise.
      */
-    bool removeJob(int index = -1);
+    Q_INVOKABLE bool removeJob(int index = -1);
+
+    /**
+     * @brief modifyJob Select a job and enter edit state
+     * @param index Row index for job to edit, if left as -1 (default), the currently selected row will be edited.
+     * @param true if sequence is in edit state. False otherwise.
+     */
+    Q_INVOKABLE bool modifyJob(int index = -1);
 
     // ////////////////////////////////////////////////////////////////////
     // Process control
@@ -259,6 +264,17 @@ public:
     void setupOpticalTrainManager();
     void refreshOpticalTrain();
 
+
+    QString opticalTrain() const
+    {
+        return opticalTrainCombo->currentText();
+    }
+
+    /**
+     * @brief Select the optical train
+     */
+    void selectOpticalTrain(QString name);
+
     // Utilities for storing stand-alone variables.
     void storeTrainKey(const QString &key, const QStringList &list);
     void storeTrainKeyString(const QString &key, const QString &str);
@@ -411,19 +427,26 @@ public:
         m_settings = newSettings;
     }
 
+    int cameraId() const
+    {
+        return m_cameraId;
+    }
+
 signals:
     // communication with other modules
     void ready();
+    void requestAction(int cameraID, CaptureWorkflowActionType action);
     void refreshCamera(uint id, bool isValid);
-    void newExposureProgress(SequenceJob *job, const QString &devicename);
-    void newDownloadProgress(double, const QString &devicename);
-    void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data, const QString &devicename = "");
+    void newExposureProgress(SequenceJob *job, const QString &trainname);
+    void newDownloadProgress(double, const QString &trainname);
+    void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data, const QString &trainname);
     void captureTarget(QString targetName);
-    void captureComplete(const QVariantMap &metadata);
-    void runAutoFocus(AutofocusReason autofocusReason, const QString &reasonInfo);
-    void resetFocus();
-    void abortFocus();
-    void adaptiveFocus();
+    void captureComplete(const QVariantMap &metadata, const QString &trainname);
+    void resetNonGuidedDither();
+    void runAutoFocus(AutofocusReason autofocusReason, const QString &reasonInfo, const QString &trainname);
+    void resetFocusFrame(const QString &trainname);
+    void abortFocus(const QString &trainname);
+    void adaptiveFocus(const QString &trainname);
     void settingsUpdated(const QVariantMap &settings);
     void sequenceChanged(const QJsonArray &sequence);
     void newLocalPreview(const QString &preview);
@@ -438,10 +461,10 @@ signals:
     void captureAborted(double exposureSeconds);
 
     // communication with other modules
-    void checkFocus(double);
-    void meridianFlipStarted();
+    void checkFocus(double, const QString &trainname);
+    void meridianFlipStarted(const QString &trainname);
     void guideAfterMeridianFlip();
-    void newStatus(CaptureState status, const QString &devicename);
+    void newStatus(CaptureState status, const QString &devicename, int cameraID);
     void suspendGuiding();
     void resumeGuiding();
     void driverTimedout(const QString &deviceName);
@@ -549,38 +572,38 @@ private:
      *        selection in the job table.
      * @return true if job updated succeeded.
      */
-    void editJobFinished();
+    Q_INVOKABLE void editJobFinished();
 
     /**
      * @brief imageCapturingCompleted Capturing a single frame completed
      */
-    void imageCapturingCompleted();
+    Q_INVOKABLE void imageCapturingCompleted();
 
     /**
      * @brief captureStopped Capturing has stopped
      */
-    void captureStopped();
+    Q_INVOKABLE void captureStopped();
 
     /**
      * @brief processFITSfinished processing new FITS data received from camera finished.
      * @param success true iff processing was successful
      */
-    void processingFITSfinished(bool success);
+    Q_INVOKABLE void processingFITSfinished(bool success);
 
     /**
      * @brief captureRunning Manage the result when capturing has been started
      */
-    void captureRunning();
+    Q_INVOKABLE void captureRunning();
 
     /**
      * @brief captureImageStarted Image capturing for the active job has started.
      */
-    void captureImageStarted();
+    Q_INVOKABLE void captureImageStarted();
 
     /**
      * @brief jobPreparationStarted Preparation actions for the current active job have beenstarted.
      */
-    void jobExecutionPreparationStarted();
+    Q_INVOKABLE void jobExecutionPreparationStarted();
 
     /**
      * @brief jobPrepared Select the job that is currently in preparation.
@@ -623,7 +646,7 @@ private:
     /**
      * @brief updateJobFromUI Update all job attributes from the UI settings.
      */
-    void updateJobFromUI(SequenceJob *job, Camera::FilenamePreviewType filenamePreview = Camera::NOT_PREVIEW);
+    void updateJobFromUI(SequenceJob *job, FilenamePreviewType filenamePreview = FILENAME_NOT_PREVIEW);
 
     /**
      * @brief syncGUIToJob Update UI to job settings
@@ -729,6 +752,14 @@ private:
     // ////////////////////////////////////////////////////////////////////
     // helper functions
     // ////////////////////////////////////////////////////////////////////
+    // object initializstion
+    void init();
+    // camera device name
+    QString getCameraName()
+    {
+        return activeCamera() == nullptr ? "" : activeCamera()->getDeviceName();
+    }
+
     // check if the upload paths are filled correctly
     bool checkUploadPaths(FilenamePreviewType filenamePreview);
 
@@ -745,7 +776,7 @@ private:
 
     // Filename preview
     void generatePreviewFilename();
-    QString previewFilename(FilenamePreviewType previewType = LOCAL_PREVIEW);
+    QString previewFilename(FilenamePreviewType previewType = FILENAME_LOCAL_PREVIEW);
 
     /**
      * @brief updateJobTableCountCell Update the job counter in the job table of a sigle job
@@ -778,7 +809,7 @@ private:
     // ////////////////////////////////////////////////////////////////////
     void appendLogText(const QString &text)
     {
-        emit newLog(text);
+        emit newLog(QString("[%1] ").arg(getCameraName()) + text);
     }
 
     // ////////////////////////////////////////////////////////////////////
