@@ -356,7 +356,7 @@ public:
     /**
      * @brief captureStarted Manage the result when capturing has been started
      */
-    void captureStarted(CameraState::CAPTUREResult rc);
+    void captureStarted(CaptureResult rc);
 
     /**
      * @brief checkNextExposure Try to start capturing the next exposure (@see startNextExposure()).
@@ -619,7 +619,7 @@ public:
      * @param continueAction action to be executed when resume after pausing
      * @return true iff capturing has been paused
      */
-    bool checkPausing(CameraState::ContinueAction continueAction);
+    bool checkPausing(CaptureContinueAction continueAction);
 
     /**
      * @brief findExecutableJob find next job to be executed
@@ -702,6 +702,7 @@ signals:
     void stopCapture(CaptureState targetState = CAPTURE_IDLE);
     void captureAborted(double exposureSeconds);
     void captureStopped();
+    void requestAction(CaptureWorkflowActionType action);
     void syncGUIToJob(SequenceJob *job);
     void updateFrameProperties(int reset);
     void updateJobTable(SequenceJob *job, bool full = false);
@@ -710,8 +711,8 @@ signals:
     void captureImageStarted();
     void captureTarget(QString targetName);
     void captureRunning();
-    void newExposureProgress(SequenceJob *job, const QString &devicename);
-    void newDownloadProgress(double downloadTimeLeft, const QString &devicename);
+    void newExposureProgress(SequenceJob *job);
+    void newDownloadProgress(double downloadTimeLeft);
     void downloadingFrame();
     void updateCaptureCountDown(int deltaMS);
     void darkFrameCompleted();
@@ -723,7 +724,7 @@ signals:
     void processingFITSfinished(bool success);
     void rotatorReverseToggled(bool enabled);
     // communication with other modules
-    void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data, const QString &devicename = "");
+    void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data);
     void newView(const QSharedPointer<FITSView> &view);
     void suspendGuiding();
     void resumeGuiding();
