@@ -17,11 +17,12 @@
 
 namespace Ekos
 {
-CameraState::CameraState(QObject *parent): QObject{parent}
+void CameraState::init()
 {
     m_sequenceQueue.reset(new SequenceQueue());
     m_refocusState.reset(new RefocusState());
     m_TargetADUTolerance = Options::calibrationADUValueTolerance();
+    connect(m_sequenceQueue.get(), &SequenceQueue::newLog, this, &CameraState::newLog);
     connect(m_refocusState.get(), &RefocusState::newLog, this, &CameraState::newLog);
 
     getGuideDeviationTimer().setInterval(GD_TIMER_TIMEOUT);
@@ -35,6 +36,11 @@ CameraState::CameraState(QObject *parent): QObject{parent}
     setSkyFlat(Options::calibrationSkyFlat());
 }
 
+CameraState::CameraState(QObject *parent): QObject{parent}
+{
+    init();
+}
+
 QList<SequenceJob *> &CameraState::allJobs()
 {
     return m_sequenceQueue->allJobs();
@@ -160,6 +166,8 @@ void CameraState::setCaptureState(CaptureState value)
     {
         case CAPTURE_IDLE:
         case CAPTURE_ABORTED:
+            emit resetNonGuidedDither();
+        /* Fall through */
         case CAPTURE_SUSPENDED:
         case CAPTURE_PAUSED:
             // meridian flip may take place if requested
@@ -170,6 +178,8 @@ void CameraState::setCaptureState(CaptureState value)
             // remember pause planning before receiving an image
             pause_planned = (m_CaptureState == CAPTURE_PAUSE_PLANNED);
             break;
+        case CAPTURE_DITHERING:
+            emit requestAction(CAPTURE_ACTION_DITHER_REQUEST);
         default:
             // do nothing
             break;
@@ -291,22 +301,22 @@ void CameraState::dustCapStateChanged(ISD::DustCap::Status status)
     switch (status)
     {
         case ISD::DustCap::CAP_ERROR:
-            setDustCapState(CameraState::CAP_ERROR);
+            setDustCapState(CAP_ERROR);
             emit newLog(i18n("Dust cap error."));
             break;
         case ISD::DustCap::CAP_PARKED:
-            setDustCapState(CameraState::CAP_PARKED);
+            setDustCapState(CAP_PARKED);
             emit newLog(i18n("Dust cap parked."));
             break;
         case ISD::DustCap::CAP_IDLE:
-            setDustCapState(CameraState::CAP_IDLE);
+            setDustCapState(CAP_IDLE);
             emit newLog(i18n("Dust cap unparked."));
             break;
         case ISD::DustCap::CAP_UNPARKING:
-            setDustCapState(CameraState::CAP_UNPARKING);
+            setDustCapState(CAP_UNPARKING);
             break;
         case ISD::DustCap::CAP_PARKING:
-            setDustCapState(CameraState::CAP_PARKING);
+            setDustCapState(CAP_PARKING);
             break;
     }
 }
@@ -412,8 +422,7 @@ bool CameraState::checkDithering()
         // reset the dither counter
         resetDitherCounter();
 
-        qCInfo(KSTARS_EKOS_CAPTURE) << "Dithering...";
-        appendLogText(i18n("Dithering..."));
+        appendLogText(i18n("Dithering requested..."));
 
         setCaptureState(CAPTURE_DITHERING);
         setDitheringState(IPS_BUSY);
@@ -513,7 +522,7 @@ void CameraState::updateMeridianFlipStage(const MeridianFlipState::MFStage &stag
             getMeridianFlipState()->processFlipCompleted();
 
             // if the capturing has been paused before the flip, reset the state to paused, otherwise to idle
-            setCaptureState(m_ContinueAction == CONTINUE_ACTION_NONE ? CAPTURE_IDLE : CAPTURE_PAUSED);
+            setCaptureState(m_ContinueAction == CAPTURE_CONTINUE_ACTION_NONE ? CAPTURE_IDLE : CAPTURE_PAUSED);
             break;
 
         default:
@@ -537,7 +546,8 @@ bool CameraState::checkMeridianFlipReady()
 
     // If active job is taking flat field image at a wall source
     // then do not flip.
-    if (m_activeJob && m_activeJob->getFrameType() == FRAME_FLAT && m_activeJob->getCalibrationPreAction() & ACTION_WALL)
+    if (m_activeJob && m_activeJob->getFrameType() == FRAME_FLAT
+            && m_activeJob->getCalibrationPreAction() & CAPTURE_PREACTION_WALL)
         return false;
 
     if (getMeridianFlipState()->getMeridianFlipStage() != MeridianFlipState::MF_REQUESTED)
@@ -549,7 +559,7 @@ bool CameraState::checkMeridianFlipReady()
     // Reset frame if we need to do focusing later on
     if (m_refocusState->isInSequenceFocus() ||
             (Options::enforceRefocusEveryN() && m_refocusState->getRefocusEveryNTimerElapsedSec() > 0))
-        emit resetFocus();
+        emit resetFocusFrame();
 
     // signal that meridian flip may take place
     if (getMeridianFlipState()->getMeridianFlipStage() == MeridianFlipState::MF_REQUESTED)
@@ -726,7 +736,23 @@ void CameraState::updateFocusState(FocusState state)
     }
 
     if (m_activeJob != nullptr)
-        m_activeJob->setFocusStatus(state);
+    {
+        // Account for in-sequence-focus action that may lead to guide suspension and resumption after it is completed successfully.
+        // In this case, since the guiding was resumed, we should honor the guiding settle duration.
+        // To satisfy this, the guide state must be guiding and focus suspend guiding should be active.
+        if (state == FOCUS_COMPLETE && Options::guidingSettle() > 0 && Options::focusSuspendGuiding() && m_GuideState == GUIDE_GUIDING)
+        {
+            // N.B. Do NOT convert to i18np since guidingRate is DOUBLE value (e.g. 1.36) so we always use plural with that.
+            appendLogText(i18n("Focus complete. Resuming in %1 seconds...", Options::guidingSettle()));
+            QTimer::singleShot(Options::guidingSettle() * 1000, this, [this, state]()
+            {
+                if (m_activeJob != nullptr)
+                    m_activeJob->setFocusStatus(state);
+            });
+        }
+        else
+            m_activeJob->setFocusStatus(state);
+    }
 }
 
 AutofocusReason CameraState::getAFReason(RefocusState::RefocusReason state, QString &reasonInfo)
@@ -808,7 +834,7 @@ bool CameraState::startFocusIfRequired()
         case RefocusState::REFOCUS_POST_MF:
             // If we are over 30 mins since last autofocus, we'll reset frame.
             if (m_refocusState->getRefocusEveryNTimerElapsedSec() >= 1800)
-                emit resetFocus();
+                emit resetFocusFrame();
 
             // force refocus
             afReason = getAFReason(reason, reasonInfo);
@@ -874,10 +900,17 @@ bool CameraState::checkAlignmentAfterFlip()
 {
     // if no meridian flip has completed, we do not touch guiding
     if (getMeridianFlipState()->getMeridianFlipStage() < MeridianFlipState::MF_COMPLETED)
+    {
+        qCDebug(KSTARS_EKOS_CAPTURE) << "checkAlignmentAfterFlip too early, meridian flip stage =" <<
+                                     getMeridianFlipState()->getMeridianFlipStage();
         return false;
+    }
     // If we do not need to align then we're done
     if (getMeridianFlipState()->resumeAlignmentAfterFlip() == false)
+    {
+        qCDebug(KSTARS_EKOS_CAPTURE) << "No alignment after flip required.";
         return false;
+    }
 
     // if we are waiting for a calibration, start it
     if (m_CaptureState < CAPTURE_ALIGNING)
@@ -1418,8 +1451,6 @@ void CameraState::removeCapturedFrameCount(const QString &signature, uint16_t co
     }
 }
 
-
-
 void CameraState::appendLogText(const QString &message)
 {
     qCInfo(KSTARS_EKOS_CAPTURE()) << message;
