@@ -18,6 +18,7 @@
 #include "placeholderpath.h"
 #include "ekos/manager.h"
 #include "ekos/auxiliary/darklibrary.h"
+#include "ekos/auxiliary/opticaltrainmanager.h"
 #include "ekos/auxiliary/profilesettings.h"
 #include "auxiliary/ksmessagebox.h"
 
@@ -48,10 +49,11 @@ namespace Ekos
 Capture::Capture()
 {
     setupUi(this);
-
     qRegisterMetaType<CaptureState>("CaptureState");
     qDBusRegisterMetaType<CaptureState>();
     new CaptureAdaptor(this);
+    // initialize the global capture state
+    m_moduleState.reset(new CaptureModuleState());
 
     // Adding the "New Tab" tab
     QWidget *newTab = new QWidget;
@@ -63,7 +65,8 @@ Capture::Capture()
 
     cameraTabs->addTab(newTab, "");
     cameraTabs->tabBar()->setTabButton(0, QTabBar::RightSide, addButton);
-
+    // Connect the close request signal to the slot
+    connect(cameraTabs, &QTabWidget::tabCloseRequested, this, &Capture::checkCloseCameraTab);
     // Create main camera
     addCamera();
 
@@ -79,29 +82,24 @@ Capture::Capture()
     registerNewModule("Mount");
 
     DarkLibrary::Instance()->setCaptureModule(this);
+
+    // connection to the global module state
+    connect(m_moduleState.get(), &CaptureModuleState::dither, this, &Capture::dither);
+    connect(m_moduleState.get(), &CaptureModuleState::newLog, this, &Capture::appendLogText);
 }
 
 
 QSharedPointer<Camera> Capture::addCamera()
 {
     QSharedPointer<Camera> newCamera;
-    newCamera.reset(new Camera(m_Cameras.count()));
+    newCamera.reset(new Camera(cameras().count()));
 
     // create the new tab and bring it to front
     const int tabIndex = cameraTabs->insertTab(std::max(0, cameraTabs->count() - 1), newCamera.get(), "new Camera");
     cameraTabs->setCurrentIndex(tabIndex);
-    // make the tab closeable if it's not the first one
-    if (tabIndex > 0)
-    {
-        QPushButton *closeButton = new QPushButton();
-        closeButton->setIcon(QIcon::fromTheme("window-close"));
-        closeButton->setFixedSize(TAB_BUTTON_SIZE, TAB_BUTTON_SIZE);
-        cameraTabs->tabBar()->setTabButton(tabIndex, QTabBar::RightSide, closeButton);
-        connect(closeButton, &QPushButton::clicked, this, [this, tabIndex]()
-        {
-            checkCloseCameraTab(tabIndex);
-        });
-    }
+    // make the tab first tab non closeable
+    if (tabIndex == 0)
+        cameraTabs->tabBar()->setTabButton(0, QTabBar::RightSide, nullptr);
 
     // forward signals from the camera
     connect(newCamera.get(), &Camera::newLog, this, &Capture::appendLogText);
@@ -121,30 +119,56 @@ QSharedPointer<Camera> Capture::addCamera()
     connect(newCamera.get(), &Camera::checkFocus, this, &Capture::checkFocus);
     connect(newCamera.get(), &Camera::newImage, this, &Capture::newImage);
     connect(newCamera.get(), &Camera::runAutoFocus, this, &Capture::runAutoFocus);
-    connect(newCamera.get(), &Camera::resetFocus, this, &Capture::resetFocus);
+    connect(newCamera.get(), &Camera::resetFocusFrame, this, &Capture::resetFocusFrame);
     connect(newCamera.get(), &Camera::abortFocus, this, &Capture::abortFocus);
-    connect(newCamera.get(), &Camera::adaptiveFocus, this, &Capture::adaptiveFocus);
+    connect(newCamera.get(), &Camera::meridianFlipStarted, this, &Capture::meridianFlipStarted);
     connect(newCamera.get(), &Camera::captureTarget, this, &Capture::captureTarget);
     connect(newCamera.get(), &Camera::guideAfterMeridianFlip, this, &Capture::guideAfterMeridianFlip);
     connect(newCamera.get(), &Camera::newStatus, this, &Capture::newStatus);
     connect(newCamera.get(), &Camera::suspendGuiding, this, &Capture::suspendGuiding);
     connect(newCamera.get(), &Camera::resumeGuiding, this, &Capture::resumeGuiding);
+    connect(newCamera.get(), &Camera::resetNonGuidedDither, this, &Capture::resetNonGuidedDither);
     connect(newCamera.get(), &Camera::driverTimedout, this, &Capture::driverTimedout);
 
-    m_Cameras.append(newCamera);
+    const QString train = findUnusedOpticalTrain();
+    // select an unused train
+    if (train != "")
+        newCamera->opticalTrainCombo->setCurrentText(train);
+    moduleState()->addCamera(newCamera);
     // update the tab text
     updateCamera(tabIndex, true);
+
     return newCamera;
 }
 
+const QString Capture::findUnusedOpticalTrain()
+{
+    QList<QString> names = OpticalTrainManager::Instance()->getTrainNames();
+    foreach(auto cam, cameras())
+        names.removeAll(cam->opticalTrain());
+
+    if (names.isEmpty())
+        return "";
+    else
+        return names.first();
+}
+
 void Capture::updateCamera(int tabID, bool isValid)
 {
     if (isValid)
     {
-        if (tabID < cameraTabs->count() && tabID < m_Cameras.count() && m_Cameras[tabID]->activeCamera() != nullptr)
+        if (tabID < cameraTabs->count() && tabID < cameras().count())
         {
-            auto name = m_Cameras[tabID]->activeCamera()->getDeviceName();
-            cameraTabs->setTabText(tabID, name);
+            auto cam = moduleState()->mutableCameras()[tabID];
+
+            if (cam->activeCamera() != nullptr)
+            {
+                auto name = cam->activeCamera()->getDeviceName();
+                cameraTabs->setTabText(tabID, name);
+            }
+
+            // update shared attributes
+            cam->state()->getRefocusState()->setForceInSeqAF(moduleState()->forceInSeqAF(cam->opticalTrain()));
         }
         else
             qCWarning(KSTARS_EKOS_CAPTURE) << "Unknown camera ID:" << tabID;
@@ -154,7 +178,7 @@ void Capture::updateCamera(int tabID, bool isValid)
 }
 
 
-bool Capture::setDome(ISD::Dome *device)
+bool Capture::setDome(ISD::Dome * device)
 {
     return process()->setDome(device);
 }
@@ -173,8 +197,8 @@ void Capture::registerNewModule(const QString &name)
 
 QString Capture::camera()
 {
-    if (devices()->getActiveCamera())
-        return devices()->getActiveCamera()->getDeviceName();
+    if (mainCameraDevices()->getActiveCamera())
+        return mainCameraDevices()->getActiveCamera()->getDeviceName();
 
     return QString();
 }
@@ -186,26 +210,42 @@ void Capture::setGuideChip(ISD::CameraChip * guideChip)
     // 2. If we have two CCDs running from ONE driver (Multiple-Devices-Per-Driver mpdp is true). Same issue as above, only one download
     // at a time.
     // After primary CCD download is complete, we resume guiding.
-    if (!devices()->getActiveCamera())
+    if (!mainCameraDevices()->getActiveCamera())
         return;
 
-    state()->setSuspendGuidingOnDownload((devices()->getActiveCamera()->getChip(
-            ISD::CameraChip::GUIDE_CCD) == guideChip) ||
-                                         (guideChip->getCCD() == devices()->getActiveCamera() &&
-                                          devices()->getActiveCamera()->getDriverInfo()->getAuxInfo().value("mdpd", false).toBool()));
+    mainCameraState()->setSuspendGuidingOnDownload((mainCameraDevices()->getActiveCamera()->getChip(
+                ISD::CameraChip::GUIDE_CCD) == guideChip) ||
+            (guideChip->getCCD() == mainCameraDevices()->getActiveCamera() &&
+             mainCameraDevices()->getActiveCamera()->getDriverInfo()->getAuxInfo().value("mdpd", false).toBool()));
+}
+
+void Capture::setFocusStatus(FocusState newstate, const QString &trainname)
+{
+    // publish to all known focusers using the same optical train (should be only one)
+    for (auto &cam : cameras())
+        if (trainname == "" || cam->opticalTrain() == trainname)
+            cam->setFocusStatus(newstate);
+}
+
+void Capture::focusAdaptiveComplete(bool success, const QString &trainname)
+{
+    // publish to all known focusers using the same optical train (should be only one)
+    for (auto &cam : cameras())
+        if (trainname == "" || cam->opticalTrain() == trainname)
+            cam->focusAdaptiveComplete(success);
 }
 
 QString Capture::filterWheel()
 {
-    if (devices()->filterWheel())
-        return devices()->filterWheel()->getDeviceName();
+    if (mainCameraDevices()->filterWheel())
+        return mainCameraDevices()->filterWheel()->getDeviceName();
 
     return QString();
 }
 
 bool Capture::setFilter(const QString &filter)
 {
-    if (devices()->filterWheel())
+    if (mainCameraDevices()->filterWheel())
     {
         mainCamera()->FilterPosCombo->setCurrentText(filter);
         return true;
@@ -219,6 +259,31 @@ QString Capture::filter()
     return mainCamera()->FilterPosCombo->currentText();
 }
 
+bool Capture::loadSequenceQueue(const QString &fileURL, QString train, bool isLead, QString targetName)
+{
+    QSharedPointer<Camera> cam;
+    if (train == "")
+        cam = mainCamera();
+    else if (isLead)
+    {
+        // take the main camera, and select the train if necessary
+        if (mainCamera()->opticalTrain() != train)
+            mainCamera()->selectOpticalTrain(train);
+
+        cam = mainCamera();
+    }
+    else
+    {
+        // find the camera, create a new one if necessary
+        int pos = findCamera(train, true);
+        if (pos < 0)
+            return false;
+        else
+            cam = camera(pos);
+    }
+    // camera found, load the sequence queue
+    return cam->loadSequenceQueue(fileURL, targetName);
+}
 
 
 void Capture::appendLogText(const QString &text)
@@ -237,79 +302,143 @@ void Capture::clearLog()
     emit newLog(QString());
 }
 
-void Capture::setFocusTemperatureDelta(double focusTemperatureDelta, double absTemperture)
+void Capture::setFocusTemperatureDelta(double focusTemperatureDelta, double absTemperture, const QString &trainname)
 {
     Q_UNUSED(absTemperture);
-    // This produces too much log spam
-    // Maybe add a threshold to report later?
-    //qCDebug(KSTARS_EKOS_CAPTURE) << "setFocusTemperatureDelta: " << focusTemperatureDelta;
-    state()->getRefocusState()->setFocusTemperatureDelta(focusTemperatureDelta);
+    // publish to all known focusers using the same optical train (should be only one)
+    for (auto &cam : cameras())
+        if (trainname == "" || cam->opticalTrain() == trainname)
+            cam->state()->getRefocusState()->setFocusTemperatureDelta(focusTemperatureDelta);
 }
 
 void Capture::setGuideDeviation(double delta_ra, double delta_dec)
 {
-    const double deviation_rms = std::hypot(delta_ra, delta_dec);
-
-    // forward it to the state machine
-    state()->setGuideDeviation(deviation_rms);
+    // forward it to the global state machine
+    moduleState()->setGuideDeviation(delta_ra, delta_dec);
 
 }
 
 void Capture::ignoreSequenceHistory()
 {
     // This function is called independently from the Scheduler or the UI, so honor the change
-    state()->setIgnoreJobProgress(true);
+    mainCameraState()->setIgnoreJobProgress(true);
+}
+
+void Capture::setCapturedFramesMap(const QString &signature, int count, QString train)
+{
+    QSharedPointer<Camera> cam;
+    if (train == "")
+        cam = mainCamera();
+    else
+    {
+        // find the camera, create a new one if necessary
+        int pos = findCamera(train, true);
+        if (pos < 0)
+            qCWarning(KSTARS_EKOS_CAPTURE) << "Cannot set the captured frames map for train" << train;
+        else
+            cam = camera(pos);
+    }
+    // camera found, set the captured frames map
+    cam->state()->setCapturedFramesCount(signature, count);
 }
 
 void Capture::setAlignStatus(AlignState newstate)
 {
     // forward it directly to the state machine
-    state()->setAlignState(newstate);
+    mainCameraState()->setAlignState(newstate);
 }
 
 void Capture::setGuideStatus(GuideState newstate)
 {
-    // forward it directly to the state machine
-    state()->setGuideState(newstate);
+    // forward to state machine
+    moduleState()->setGuideStatus(newstate);
 }
 
 bool Capture::setVideoLimits(uint16_t maxBufferSize, uint16_t maxPreviewFPS)
 {
-    if (devices()->getActiveCamera() == nullptr)
+    if (mainCameraDevices()->getActiveCamera() == nullptr)
         return false;
 
-    return devices()->getActiveCamera()->setStreamLimits(maxBufferSize, maxPreviewFPS);
+    return mainCameraDevices()->getActiveCamera()->setStreamLimits(maxBufferSize, maxPreviewFPS);
+}
+
+QString Capture::start(QString train)
+{
+    QSharedPointer<Camera> cam;
+    if (train == "")
+        cam = mainCamera();
+    else
+    {
+        // find the camera, create a new one if necessary
+        int pos = findCamera(train, true);
+        if (pos < 0)
+        {
+            qCWarning(KSTARS_EKOS_CAPTURE) << "Cannot start capturing for train" << train;
+            return "";
+        }
+        else
+            cam = camera(pos);
+    }
+    // camera found, start capturing
+    cam->start();
+    // return the real train name
+    return cam->opticalTrain();
+}
+
+void Capture::abort(QString train)
+{
+    QSharedPointer<Camera> cam;
+    if (train == "")
+        for (auto cam : cameras())
+            cam->abort();
+    else
+    {
+        int pos = findCamera(train, false);
+        if (pos < 0)
+        {
+            qCWarning(KSTARS_EKOS_CAPTURE) << "Cannot abort capturing for train" << train;
+            return;
+        }
+        else
+            cam = camera(pos);
+
+        // camera found, abort capturing
+        cam->abort();
+    }
 }
 
 QSharedPointer<Camera> &Capture::camera(int i)
 {
-    if (i < m_Cameras.count())
-        return m_Cameras[i];
+    if (i < cameras().count())
+        return moduleState()->mutableCameras()[i];
     else
     {
         qCWarning(KSTARS_EKOS_CAPTURE) << "Unknown camera ID:" << i;
-        return m_Cameras[0];
+        return moduleState()->mutableCameras()[0];
     }
 }
 
 void Ekos::Capture::closeCameraTab(int tabIndex)
 {
     cameraTabs->removeTab(tabIndex);
-    camera(tabIndex).clear();
-    m_Cameras.removeAt(tabIndex);
+    moduleState()->removeCamera(tabIndex);
     // select the next one on the left
     cameraTabs->setCurrentIndex(std::max(0, tabIndex - 1));
 }
 
 void Capture::checkCloseCameraTab(int tabIndex)
 {
-    if (m_Cameras[tabIndex]->state()->isBusy())
+    // ignore close event from the "Add" tab
+    if (tabIndex == cameraTabs->count() - 1)
+        return;
+
+    if (moduleState()->mutableCameras()[tabIndex]->state()->isBusy())
     {
         // if accept has been clicked, abort and close the tab
         connect(KSMessageBox::Instance(), &KSMessageBox::accepted, this, [this, &tabIndex]()
         {
             KSMessageBox::Instance()->disconnect(this);
-            m_Cameras[tabIndex]->abort();
+            moduleState()->mutableCameras()[tabIndex]->abort();
             closeCameraTab(tabIndex);
         });
         // if cancel has been clicked, do not close the tab
@@ -319,7 +448,8 @@ void Capture::checkCloseCameraTab(int tabIndex)
         });
 
         KSMessageBox::Instance()->warningContinueCancel(i18n("Camera %1 is busy. Abort to close?",
-                m_Cameras[tabIndex]->activeCamera()->getDeviceName()), i18n("Stop capturing"), 30, false, i18n("Abort"));
+                moduleState()->mutableCameras()[tabIndex]->activeCamera()->getDeviceName()), i18n("Stop capturing"), 30, false,
+                i18n("Abort"));
     }
     else
     {
@@ -327,12 +457,35 @@ void Capture::checkCloseCameraTab(int tabIndex)
     }
 }
 
-QSharedPointer<Camera> Capture::mainCamera() const
+const QSharedPointer<Camera> Capture::mainCamera() const
 {
-    if (m_Cameras.size() > 0)
-        return m_Cameras[0];
+    if (cameras().size() > 0)
+        return moduleState()->cameras()[0];
     else
-        return QSharedPointer<Camera>(new Camera());
+    {
+        QSharedPointer<CaptureModuleState> cms;
+        cms.reset(new CaptureModuleState());
+        return QSharedPointer<Camera>(new Camera(cms));
+    }
+}
+
+int Capture::findCamera(QString train, bool addIfNecessary)
+{
+    for (auto &cam : cameras())
+    {
+        if (cam->opticalTrain() == train)
+            return cam->m_cameraId;
+    }
+
+    // none found
+    if (addIfNecessary)
+    {
+        QSharedPointer<Camera> cam = addCamera();
+        cam->selectOpticalTrain(train);
+        return cam->m_cameraId;
+    }
+    // nothing found
+    return -1;
 }
 
 void Capture::setMountStatus(ISD::Mount::Status newState)
@@ -347,16 +500,16 @@ void Capture::setMountStatus(ISD::Mount::Status newState)
             // Only disable when button is "Start", and not "Stopped"
             // If mount is in motion, Stopped button should always be enabled to terminate
             // the sequence
-            if (state()->isBusy() == false)
+            if (mainCameraState()->isBusy() == false)
                 mainCamera()->startB->setEnabled(false);
             break;
 
         default:
-            if (state()->isBusy() == false)
+            if (mainCameraState()->isBusy() == false)
             {
                 mainCamera()->previewB->setEnabled(true);
-                if (devices()->getActiveCamera())
-                    mainCamera()->liveVideoB->setEnabled(devices()->getActiveCamera()->hasVideoStream());
+                if (mainCameraDevices()->getActiveCamera())
+                    mainCamera()->liveVideoB->setEnabled(mainCameraDevices()->getActiveCamera()->hasVideoStream());
                 mainCamera()->startB->setEnabled(true);
             }
 
@@ -369,24 +522,35 @@ void Capture::setAlignResults(double solverPA, double ra, double de, double pixs
     Q_UNUSED(ra)
     Q_UNUSED(de)
     Q_UNUSED(pixscale)
-    if (devices()->rotator() && mainCamera()->m_RotatorControlPanel)
+    if (mainCameraDevices()->rotator() && mainCamera()->m_RotatorControlPanel)
         mainCamera()->m_RotatorControlPanel->refresh(solverPA);
 }
 
 void Capture::setMeridianFlipState(QSharedPointer<MeridianFlipState> newstate)
 {
-    state()->setMeridianFlipState(newstate);
-    connect(state()->getMeridianFlipState().get(), &MeridianFlipState::newLog, this, &Capture::appendLogText);
+    mainCameraState()->setMeridianFlipState(newstate);
+    connect(mainCameraState()->getMeridianFlipState().get(), &MeridianFlipState::newLog, this, &Capture::appendLogText);
+    connect(mainCameraState()->getMeridianFlipState().get(), &MeridianFlipState::newMountMFStatus, moduleState().get(),
+            &CaptureModuleState::updateMFMountState);
 }
 
 bool Capture::hasCoolerControl()
 {
-    return process()->hasCoolerControl();
+    bool result = false;
+    for (auto &cam : cameras())
+        if (cam->process()->hasCoolerControl())
+            result |= cam->process()->hasCoolerControl();
+    return result;
 }
 
 bool Capture::setCoolerControl(bool enable)
 {
-    return process()->setCoolerControl(enable);
+    bool result = true;
+    for (auto &cam : cameras())
+        if (cam->process()->hasCoolerControl())
+            result &= cam->process()->setCoolerControl(enable);
+
+    return result;
 }
 
 void Capture::removeDevice(const QSharedPointer<ISD::GenericDevice> &device)
@@ -402,8 +566,22 @@ QString Capture::getTargetName()
         return "";
 }
 
-void Capture::setHFR(double newHFR, int, bool inAutofocus)
+void Capture::setHFR(double newHFR, int, bool inAutofocus, const QString &trainname)
 {
-    state()->getRefocusState()->setFocusHFR(newHFR, inAutofocus);
+    // publish to all known focusers using the same optical train (should be only one)
+    for (auto &cam : cameras())
+        if (trainname == "" || cam->opticalTrain() == trainname)
+            cam->state()->getRefocusState()->setFocusHFR(newHFR, inAutofocus);
 }
+
+void Capture::inSequenceAFRequested(bool requested, const QString &trainname)
+{
+    // publish to all known cameras using the same optical train (should be only one)
+    for (auto &cam : cameras())
+        if (trainname == "" || cam->opticalTrain() == trainname)
+            // set the value directly in the camera's state
+            cam->state()->getRefocusState()->setForceInSeqAF(requested);
+
+    moduleState()->setForceInSeqAF(requested, trainname);
 }
+} // namespace
