@@ -9,6 +9,7 @@
 #include "ui_capture.h"
 
 #include "camera.h"
+#include "capturemodulestate.h"
 #include "ekos/manager/meridianflipstate.h"
 #include "ekos/ekos.h"
 #include "ekos/auxiliary/opticaltrainsettings.h"
@@ -142,18 +143,17 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE QString getSequenceQueueStatus()
         {
-            return state()->sequenceQueueStatus();
+            return mainCameraState()->sequenceQueueStatus();
         }
 
         /** DBUS interface function.
              * Loads the Ekos Sequence Queue file in the Sequence Queue. Jobs are appended to existing jobs.
              * @param fileURL full URL of the filename
+             * @param train name of the optical train to be used
+             * @param lead lead or follower job?
              * @param targetName override the target in the sequence queue file (necessary for using the target of the scheduler)
              */
-        Q_SCRIPTABLE bool loadSequenceQueue(const QString &fileURL, QString targetName = "")
-        {
-            return mainCamera()->loadSequenceQueue(fileURL, targetName);
-        }
+        Q_SCRIPTABLE bool loadSequenceQueue(const QString &fileURL, QString train = "", bool isLead = true, QString targetName = "");
 
         /** DBUS interface function.
              * Saves the Sequence Queue to the Ekos Sequence Queue file.
@@ -200,7 +200,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE double getProgressPercentage()
         {
-            return state()->progressPercentage();
+            return mainCameraState()->progressPercentage();
         }
 
         /** DBUS interface function.
@@ -216,7 +216,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getJobCount()
         {
-            return state()->allJobs().count();
+            return mainCameraState()->allJobs().count();
         }
 
         /** DBUS interface function.
@@ -224,7 +224,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getPendingJobCount()
         {
-            return state()->pendingJobCount();
+            return mainCameraState()->pendingJobCount();
         }
 
         /** DBUS interface function.
@@ -232,7 +232,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getActiveJobID()
         {
-            return state()->activeJobID();
+            return mainCameraState()->activeJobID();
         }
 
         /** DBUS interface function.
@@ -240,7 +240,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getActiveJobRemainingTime()
         {
-            return state()->activeJobRemainingTime();
+            return mainCameraState()->activeJobRemainingTime();
         }
 
         /** DBUS interface function.
@@ -248,7 +248,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getOverallRemainingTime()
         {
-            return state()->overallRemainingTime();
+            return mainCameraState()->overallRemainingTime();
         }
 
         /** DBUS interface function.
@@ -257,7 +257,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE QString getJobState(int id)
         {
-            return state()->jobState(id);
+            return mainCameraState()->jobState(id);
         }
 
         /** DBUS interface function.
@@ -266,7 +266,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE QString getJobFilterName(int id)
         {
-            return state()->jobFilterName(id);
+            return mainCameraState()->jobFilterName(id);
         }
 
         /** DBUS interface function.
@@ -275,7 +275,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getJobImageProgress(int id)
         {
-            return state()->jobImageProgress(id);
+            return mainCameraState()->jobImageProgress(id);
         }
 
         /** DBUS interface function.
@@ -284,7 +284,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE int getJobImageCount(int id)
         {
-            return state()->jobImageCount(id);
+            return mainCameraState()->jobImageCount(id);
         }
 
         /** DBUS interface function.
@@ -293,7 +293,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE double getJobExposureProgress(int id)
         {
-            return state()->jobExposureProgress(id);
+            return mainCameraState()->jobExposureProgress(id);
         }
 
         /** DBUS interface function.
@@ -302,7 +302,7 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE double getJobExposureDuration(int id)
         {
-            return state()->jobExposureDuration(id);
+            return mainCameraState()->jobExposureDuration(id);
         }
 
         /** DBUS interface function.
@@ -311,7 +311,24 @@ class Capture : public QWidget, public Ui::Capture
              */
         Q_SCRIPTABLE CCDFrameType getJobFrameType(int id)
         {
-            return state()->jobFrameType(id);
+            return mainCameraState()->jobFrameType(id);
+        }
+
+        /** DBUS interface function.
+             * @param id job number. Job IDs start from 0 to N-1.
+             * @return Returns the placeholder format of the job.
+             */
+        Q_SCRIPTABLE QString getJobPlaceholderFormat()
+        {
+            return mainCamera()->placeholderFormatT->text();
+        }
+
+        /** DBUS interface function.
+             * @return Returns the Preview Filename of the job.
+             */
+        Q_SCRIPTABLE QString getJobPreviewFileName()
+        {
+            return mainCamera()->previewFilename();
         }
 
         /** DBUS interface function.
@@ -334,11 +351,7 @@ class Capture : public QWidget, public Ui::Capture
              * is set to 1, then we continue to capture frame #2 even though the number of completed images is already
              * larger than required count (5). It is mostly used in conjunction with Ekos Scheduler.
              */
-        Q_SCRIPTABLE Q_NOREPLY void setCapturedFramesMap(const QString &signature, int count)
-        {
-            state()->setCapturedFramesCount(signature, static_cast<ushort>(count));
-        };
-
+        Q_SCRIPTABLE Q_NOREPLY void setCapturedFramesMap(const QString &signature, int count, QString train = "");
 
         /** DBUS interface function.
          *  List of logging entries for the capture module.
@@ -361,10 +374,15 @@ class Capture : public QWidget, public Ui::Capture
          */
         Q_SCRIPTABLE CaptureState status()
         {
-            return state()->getCaptureState();
+            return mainCameraState()->getCaptureState();
         }
         /** @} end of group CaptureDBusInterface */
 
+        QSharedPointer<CaptureModuleState> moduleState() const
+        {
+            return m_moduleState;
+        }
+
         // ////////////////////////////////////////////////////////////////////
         // Access to the cameras
         // ////////////////////////////////////////////////////////////////////
@@ -373,7 +391,15 @@ class Capture : public QWidget, public Ui::Capture
 
         void checkCloseCameraTab(int tabIndex);
 
-        QSharedPointer<Camera> mainCamera() const;
+        const QSharedPointer<Camera> mainCamera() const;
+
+        /**
+         * @brief find the camera using the given train
+         * @param train optical train name
+         * @param addIfNecessary if true, add a new camera with the given train, if none uses this train
+         * @return index in the lost of cameras (@see #camera(int))
+         */
+        int findCamera(QString train, bool addIfNecessary);
 
         // ////////////////////////////////////////////////////////////////////
         // Changing the devices used by Capture
@@ -428,7 +454,7 @@ class Capture : public QWidget, public Ui::Capture
          */
         const QJsonArray &getSequence() const
         {
-            return state()->getSequence();
+            return mainCameraState()->getSequence();
         }        
 
         /**
@@ -441,7 +467,7 @@ class Capture : public QWidget, public Ui::Capture
 
         const QList<QSharedPointer<Camera>> &cameras() const
         {
-            return m_Cameras;
+            return moduleState()->cameras();
         }
 
 public slots:
@@ -465,11 +491,9 @@ public slots:
              *    all jobs are are reset (@see reset()) and the first one from the list is selected.
              *    If no, the user is asked whether the jobs should be reset. If the user declines,
              *    starting is aborted.
+             *    @return train name of the camera
              */
-        Q_SCRIPTABLE Q_NOREPLY void start()
-        {
-            mainCamera()->start();
-        }
+        Q_SCRIPTABLE QString start(QString train = "");
 
         /** DBUS interface function.
              * Stops currently running jobs:
@@ -488,10 +512,7 @@ public slots:
         /** DBUS interface function.
              * Aborts all jobs and mark current state as ABORTED. It simply calls stop(CAPTURE_ABORTED)
              */
-        Q_SCRIPTABLE Q_NOREPLY void abort()
-        {
-            mainCamera()->abort();
-        }
+        Q_SCRIPTABLE Q_NOREPLY void abort(QString train = "");
 
         /** DBUS interface function.
              * Aborts all jobs and mark current state as SUSPENDED. It simply calls stop(CAPTURE_SUSPENDED)
@@ -616,33 +637,35 @@ public slots:
         // Auto Focus
         /**
          * @brief setFocusStatus Forward the new focus state to the capture module state machine
+         * @param trainname name of the optical train to select the focuser
          */
-        void setFocusStatus(FocusState newstate)
-        {
-            mainCamera()->setFocusStatus(newstate);
-        }
-
+        void setFocusStatus(FocusState newstate, const QString &trainname);
 
         // Adaptive Focus
         /**
          * @brief focusAdaptiveComplete Forward the new focus state to the capture module state machine
+         * @param trainname name of the optical train to select the focuser
          */
-        void focusAdaptiveComplete(bool success)
-        {
-            // directly forward it to the state machine
-            mainCamera()->focusAdaptiveComplete(success);
-        }
+        void focusAdaptiveComplete(bool success, const QString &trainname);
 
         /**
-         * @brief updateAdaptiveFocusStatus Handle new focus state
+         * @brief setFocusTemperatureDelta update the focuser's temperature delta
+         * @param trainname name of the optical train to select the focuser
          */
-
-        void setFocusTemperatureDelta(double focusTemperatureDelta, double absTemperature);
+        void setFocusTemperatureDelta(double focusTemperatureDelta, double absTemperature, const QString &trainname);
 
         /**
          * @brief setHFR Receive the measured HFR value of the latest frame
+         * @param trainname name of the optical train to select the focuser
          */
-        void setHFR(double newHFR, int position, bool inAutofocus);
+        void setHFR(double newHFR, int position, bool inAutofocus, const QString &trainname);
+
+        /**
+         * @brief inSequenceAFRequested Focuser informs that the user wishes an AF run as soon as possible.
+         * @param requested true iff AF is requested.
+         * @param trainname name of the optical train to select the focuser
+         */
+        void inSequenceAFRequested(bool requested, const QString &trainname);
 
         // Guide
         void setGuideStatus(GuideState newstate);
@@ -670,27 +693,29 @@ public slots:
 
     signals:
         Q_SCRIPTABLE void newLog(const QString &text);
-        Q_SCRIPTABLE void meridianFlipStarted();
+        Q_SCRIPTABLE void meridianFlipStarted(const QString &trainname);
         Q_SCRIPTABLE void guideAfterMeridianFlip();
-        Q_SCRIPTABLE void newStatus(CaptureState status, const QString &devicename);
-        Q_SCRIPTABLE void captureComplete(const QVariantMap &metadata);
+        Q_SCRIPTABLE void newStatus(CaptureState status, const QString &trainname, int cameraID);
+        Q_SCRIPTABLE void captureComplete(const QVariantMap &metadata, const QString &trainname);
 
         void newFilterStatus(FilterState state);
 
         void ready();
 
         // communication with other modules
-        void checkFocus(double);
-        void runAutoFocus(AutofocusReason autofocusReason, const QString &reasonInfo);
-        void resetFocus();
-        void abortFocus();
-        void adaptiveFocus();
+        void checkFocus(double, const QString &opticaltrain);
+        void runAutoFocus(AutofocusReason autofocusReason, const QString &reasonInfo, const QString &trainname);
+        void resetFocusFrame(const QString &trainname);
+        void abortFocus(const QString &trainname);
+        void adaptiveFocus(const QString &trainname);
         void suspendGuiding();
         void resumeGuiding();
+        void dither();
+        void resetNonGuidedDither();
         void captureTarget(QString targetName);
-        void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data, const QString &devicename = "");
-        void newExposureProgress(SequenceJob *job, const QString &devicename);
-        void newDownloadProgress(double, const QString &devicename);
+        void newImage(SequenceJob *job, const QSharedPointer<FITSData> &data, const QString &trainname);
+        void newExposureProgress(SequenceJob *job, const QString &trainname);
+        void newDownloadProgress(double, const QString &trainname);
         void sequenceChanged(const QJsonArray &sequence);
         void settingsUpdated(const QVariantMap &settings);        
         void newLocalPreview(const QString &preview);
@@ -722,21 +747,27 @@ public slots:
         // ////////////////////////////////////////////////////////////////////
 
         // shortcut for the module state
-        QSharedPointer<CameraState> state() const
+        QSharedPointer<CameraState> mainCameraState() const
         {
             return mainCamera()->state();
         }
         // shortcut to device adapter
-        QSharedPointer<CaptureDeviceAdaptor> devices()
+        QSharedPointer<CaptureDeviceAdaptor> mainCameraDevices()
         {
             return mainCamera()->devices();
         }
         // shortcut for the active job
         SequenceJob *activeJob() const
         {
-            return state()->getActiveJob();
+            return mainCameraState()->getActiveJob();
         }
 
+        /**
+         * @brief findUnusedOpticalTrain Find the name of the first optical train that is not used by another tab
+         * @return
+         */
+        const QString findUnusedOpticalTrain();
+
         /**
          * @brief Sync refocus options to the GUI settings
          */
@@ -759,7 +790,8 @@ public slots:
         int seqTotalCount;
         int seqCurrentCount { 0 };
 
-        QList<QSharedPointer<Camera>> m_Cameras;
+        // overall state
+        QSharedPointer<CaptureModuleState> m_moduleState;
 
         QPointer<QDBusInterface> mountInterface;
 
