@@ -148,6 +148,7 @@ void CaptureDeviceAdaptor::connectMount(SequenceJobState *state)
 
     connect(state, &SequenceJobState::slewTelescope, this, &CaptureDeviceAdaptor::slewTelescope);
     connect(state, &SequenceJobState::setScopeTracking, this, &CaptureDeviceAdaptor::setScopeTracking);
+    connect(state, &SequenceJobState::readCurrentMountParkState, this, &CaptureDeviceAdaptor::readCurrentMountParkState);
     connect(state, &SequenceJobState::setScopeParked, this, &CaptureDeviceAdaptor::setScopeParked);
 
     connect(this, &CaptureDeviceAdaptor::scopeStatusChanged, state, &SequenceJobState::scopeStatusChanged);
@@ -445,6 +446,12 @@ void CaptureDeviceAdaptor::readCurrentState(CaptureState state)
     }
 }
 
+void CaptureDeviceAdaptor::readCurrentMountParkState()
+{
+    if (m_ActiveMount != nullptr)
+        emit scopeParkStatusChanged(m_ActiveMount->parkStatus());
+}
+
 void CaptureDeviceAdaptor::setCCDTemperature(double temp)
 {
     if (m_ActiveCamera != nullptr)
