@@ -141,6 +141,10 @@ bool SequenceJobState::areActionsReady()
 
 void SequenceJobState::checkAllActionsReady()
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     switch (m_PreparationState)
     {
         // capture preparation
@@ -223,7 +227,7 @@ void SequenceJobState::checkAllActionsReady()
 
 void SequenceJobState::setAllActionsReady()
 {
-    QMutableMapIterator<CameraState::PrepareActions, bool> it(prepareActions);
+    QMutableMapIterator<CaptureWorkflowActionType, bool> it(prepareActions);
 
     while (it.hasNext())
     {
@@ -231,9 +235,9 @@ void SequenceJobState::setAllActionsReady()
         it.setValue(true);
     }
     // reset the initialization state
-    for (CameraState::PrepareActions action :
+    for (CaptureWorkflowActionType action :
             {
-                CameraState::ACTION_FILTER, CameraState::ACTION_ROTATOR, CameraState::ACTION_TEMPERATURE
+                CAPTURE_ACTION_FILTER, CAPTURE_ACTION_ROTATOR, CAPTURE_ACTION_TEMPERATURE
             })
         setInitialized(action, false);
 }
@@ -242,9 +246,9 @@ void SequenceJobState::prepareTargetFilter(CCDFrameType frameType, bool isPrevie
 {
     if (targetFilterID != INVALID_VALUE)
     {
-        if (isInitialized(CameraState::ACTION_FILTER) == false)
+        if (isInitialized(CAPTURE_ACTION_FILTER) == false)
         {
-            prepareActions[CameraState::ACTION_FILTER] = false;
+            prepareActions[CAPTURE_ACTION_FILTER] = false;
 
             // Don't perform autofocus on preview or calibration frames or if Autofocus is not ready yet.
             if (isPreview || frameType != FRAME_LIGHT || autoFocusReady == false)
@@ -255,7 +259,7 @@ void SequenceJobState::prepareTargetFilter(CCDFrameType frameType, bool isPrevie
         else if (targetFilterID != m_CameraState->currentFilterID)
         {
             // mark filter preparation action
-            prepareActions[CameraState::ACTION_FILTER] = false;
+            prepareActions[CAPTURE_ACTION_FILTER] = false;
 
             // determine policy
             m_filterPolicy = FilterManager::ALL_POLICIES;
@@ -277,12 +281,12 @@ void SequenceJobState::prepareTemperatureCheck(bool enforceCCDTemp)
 
     if (m_enforceTemperature)
     {
-        prepareActions[CameraState::ACTION_TEMPERATURE] = false;
-        if (isInitialized(CameraState::ACTION_TEMPERATURE))
+        prepareActions[CAPTURE_ACTION_TEMPERATURE] = false;
+        if (isInitialized(CAPTURE_ACTION_TEMPERATURE))
         {
             // ignore the next value since after setting temperature the next received value will be
             // exactly this value no matter what the CCD temperature
-            ignoreNextValue[CameraState::ACTION_TEMPERATURE] = true;
+            ignoreNextValue[CAPTURE_ACTION_TEMPERATURE] = true;
             // request setting temperature
             emit setCCDTemperature(targetTemperature);
             emit prepareState(CAPTURE_SETTING_TEMPERATURE);
@@ -298,9 +302,9 @@ void SequenceJobState::prepareRotatorCheck()
 {
     if (targetPositionAngle > Ekos::INVALID_VALUE)
     {
-        if (isInitialized(CameraState::ACTION_ROTATOR))
+        if (isInitialized(CAPTURE_ACTION_ROTATOR))
         {
-            prepareActions[CameraState::ACTION_ROTATOR] = false;
+            prepareActions[CAPTURE_ACTION_ROTATOR] = false;
             double rawAngle = RotatorUtils::Instance()->calcRotatorAngle(targetPositionAngle);
             emit prepareState(CAPTURE_SETTING_ROTATOR);
             emit setRotatorAngle(rawAngle);
@@ -315,19 +319,19 @@ IPState SequenceJobState::checkCalibrationPreActionsReady()
 {
     IPState result = IPS_OK;
 
-    if (m_CalibrationPreAction & ACTION_WALL)
+    if (m_CalibrationPreAction & CAPTURE_PREACTION_WALL)
         result = checkWallPositionReady(FRAME_FLAT);
 
     if (result != IPS_OK)
         return result;
 
-    if (m_CalibrationPreAction & ACTION_PARK_MOUNT)
+    if (m_CalibrationPreAction & CAPTURE_PREACTION_PARK_MOUNT)
         result = checkPreMountParkReady();
 
     if (result != IPS_OK)
         return result;
 
-    if (m_CalibrationPreAction & ACTION_PARK_DOME)
+    if (m_CalibrationPreAction & CAPTURE_PREACTION_PARK_DOME)
         result = checkPreDomeParkReady();
 
     return result;
@@ -341,7 +345,7 @@ IPState SequenceJobState::checkFlatsCoverReady()
         if (m_CameraState->hasDustCap && m_CameraState->hasLightBox)
             return checkDustCapReady(FRAME_FLAT);
         // In case we have a wall action then we are facing a flat light source and we can immediately continue to next step
-        else if (m_CalibrationPreAction & ACTION_WALL)
+        else if (m_CalibrationPreAction & CAPTURE_PREACTION_WALL)
             return IPS_OK;
         else
         {
@@ -370,7 +374,7 @@ IPState SequenceJobState::checkDarksCoverReady()
         if (m_CameraState->hasDustCap)
             return checkDustCapReady(FRAME_DARK);
         // In case we have a wall action then we are facing a designated location and we can immediately continue to next step
-        else if (m_CalibrationPreAction & ACTION_WALL)
+        else if (m_CalibrationPreAction & CAPTURE_PREACTION_WALL)
             return IPS_OK;
         else
             return checkManualCoverReady(false);
@@ -394,7 +398,7 @@ IPState SequenceJobState::checkManualCoverReady(bool lightSourceRequired)
         return IPS_BUSY;
     }
     else if (!lightSourceRequired && m_CameraState->m_ManualCoverState != CameraState::MANUAL_COVER_CLOSED_DARK &&
-             m_CameraState->shutterStatus == CameraState::SHUTTER_NO)
+             m_CameraState->shutterStatus == SHUTTER_NO)
     {
         if (coverQueryState == CAL_CHECK_CONFIRMATION)
             return IPS_BUSY;
@@ -412,34 +416,34 @@ IPState SequenceJobState::checkManualCoverReady(bool lightSourceRequired)
 IPState SequenceJobState::checkDustCapReady(CCDFrameType frameType)
 {
     // turning on flat light running
-    if (m_CameraState->getLightBoxLightState() == CameraState::CAP_LIGHT_BUSY  ||
-            m_CameraState->getDustCapState() == CameraState::CAP_PARKING ||
-            m_CameraState->getDustCapState() == CameraState::CAP_UNPARKING)
+    if (m_CameraState->getLightBoxLightState() == CAP_LIGHT_BUSY  ||
+            m_CameraState->getDustCapState() == CAP_PARKING ||
+            m_CameraState->getDustCapState() == CAP_UNPARKING)
         return IPS_BUSY;
     // error occured
-    if (m_CameraState->getDustCapState() == CameraState::CAP_ERROR)
+    if (m_CameraState->getDustCapState() == CAP_ERROR)
         return IPS_ALERT;
 
     auto captureLights = (frameType == FRAME_LIGHT);
 
     // for flats open the cap and close it otherwise
-    CameraState::CapState targetCapState = captureLights ? CameraState::CAP_IDLE : CameraState::CAP_PARKED;
+    CapState targetCapState = captureLights ? CAP_IDLE : CAP_PARKED;
     // If cap is parked, unpark it since dark cap uses external light source.
     if (m_CameraState->hasDustCap && m_CameraState->getDustCapState() != targetCapState)
     {
-        m_CameraState->setDustCapState(captureLights ? CameraState::CAP_UNPARKING : CameraState::CAP_PARKING);
+        m_CameraState->setDustCapState(captureLights ? CAP_UNPARKING : CAP_PARKING);
         emit parkDustCap(!captureLights);
         emit newLog(captureLights ? i18n("Unparking dust cap...") : i18n("Parking dust cap..."));
         return IPS_BUSY;
     }
 
     auto captureFlats = (frameType == FRAME_FLAT);
-    CameraState::LightState targetLightBoxStatus = captureFlats ? CameraState::CAP_LIGHT_ON :
-            CameraState::CAP_LIGHT_OFF;
+    LightState targetLightBoxStatus = captureFlats ? CAP_LIGHT_ON :
+                                      CAP_LIGHT_OFF;
 
     if (m_CameraState->hasLightBox && m_CameraState->getLightBoxLightState() != targetLightBoxStatus)
     {
-        m_CameraState->setLightBoxLightState(CameraState::CAP_LIGHT_BUSY);
+        m_CameraState->setLightBoxLightState(CAP_LIGHT_BUSY);
         emit setLightBoxLight(captureFlats);
         emit newLog(captureFlats ? i18n("Turn light box light on...") : i18n("Turn light box light off..."));
         return IPS_BUSY;
@@ -479,14 +483,14 @@ IPState SequenceJobState::checkWallPositionReady(CCDFrameType frametype)
 
         // wall position reached, check if we have a light box to turn on for flats and off otherwise
         bool captureFlats = (frametype == FRAME_FLAT);
-        CameraState::LightState targetLightState = (captureFlats ? CameraState::CAP_LIGHT_ON :
-                CameraState::CAP_LIGHT_OFF);
+        LightState targetLightState = (captureFlats ? CAP_LIGHT_ON :
+                                       CAP_LIGHT_OFF);
 
         if (m_CameraState->hasLightBox == true)
         {
             if (m_CameraState->getLightBoxLightState() != targetLightState)
             {
-                m_CameraState->setLightBoxLightState(CameraState::CAP_LIGHT_BUSY);
+                m_CameraState->setLightBoxLightState(CAP_LIGHT_BUSY);
                 emit setLightBoxLight(captureFlats);
                 emit newLog(captureFlats ? i18n("Turn light box light on...") : i18n("Turn light box light off..."));
                 return IPS_BUSY;
@@ -577,12 +581,12 @@ IPState SequenceJobState::checkFlatSyncFocus()
 
 IPState SequenceJobState::checkHasShutter()
 {
-    if (m_CameraState->shutterStatus == CameraState::SHUTTER_BUSY)
+    if (m_CameraState->shutterStatus == SHUTTER_BUSY)
         return IPS_BUSY;
-    if (m_CameraState->shutterStatus != CameraState::SHUTTER_UNKNOWN)
+    if (m_CameraState->shutterStatus != SHUTTER_UNKNOWN)
         return IPS_OK;
     // query the status
-    m_CameraState->shutterStatus = CameraState::SHUTTER_BUSY;
+    m_CameraState->shutterStatus = SHUTTER_BUSY;
     emit queryHasShutter();
     return IPS_BUSY;
 }
@@ -590,11 +594,11 @@ IPState SequenceJobState::checkHasShutter()
 IPState SequenceJobState::checkLightFrameScopeCoverOpen()
 {
     // Account for light box only (no dust cap)
-    if (m_CameraState->hasLightBox && m_CameraState->getLightBoxLightState() != CameraState::CAP_LIGHT_OFF)
+    if (m_CameraState->hasLightBox && m_CameraState->getLightBoxLightState() != CAP_LIGHT_OFF)
     {
-        if (m_CameraState->getLightBoxLightState() != CameraState::CAP_LIGHT_BUSY)
+        if (m_CameraState->getLightBoxLightState() != CAP_LIGHT_BUSY)
         {
-            m_CameraState->setLightBoxLightState(CameraState::CAP_LIGHT_BUSY);
+            m_CameraState->setLightBoxLightState(CAP_LIGHT_BUSY);
             emit setLightBoxLight(false);
             emit newLog(i18n("Turn light box light off..."));
         }
@@ -604,11 +608,11 @@ IPState SequenceJobState::checkLightFrameScopeCoverOpen()
     // If we have a dust cap, then we must unpark
     if (m_CameraState->hasDustCap)
     {
-        if (m_CameraState->getDustCapState() != CameraState::CAP_IDLE)
+        if (m_CameraState->getDustCapState() != CAP_IDLE)
         {
-            if (m_CameraState->getDustCapState() != CameraState::CAP_UNPARKING)
+            if (m_CameraState->getDustCapState() != CAP_UNPARKING)
             {
-                m_CameraState->setDustCapState(CameraState::CAP_UNPARKING);
+                m_CameraState->setDustCapState(CAP_UNPARKING);
                 emit parkDustCap(false);
                 emit newLog(i18n("Unparking dust cap..."));
             }
@@ -637,60 +641,68 @@ IPState SequenceJobState::checkLightFrameScopeCoverOpen()
     return IPS_OK;
 }
 
-bool SequenceJobState::isInitialized(CameraState::PrepareActions action)
+bool SequenceJobState::isInitialized(CaptureWorkflowActionType action)
 {
     return m_CameraState.data()->isInitialized[action];
 }
 
-void SequenceJobState::setInitialized(CameraState::PrepareActions action, bool init)
+void SequenceJobState::setInitialized(CaptureWorkflowActionType action, bool init)
 {
     m_CameraState.data()->isInitialized[action] = init;
 }
 
 void SequenceJobState::setCurrentFilterID(int value)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     m_CameraState->currentFilterID = value;
-    if (isInitialized(CameraState::ACTION_FILTER) == false && value != targetFilterID)
+    if (isInitialized(CAPTURE_ACTION_FILTER) == false && value != targetFilterID)
     {
         // mark filter preparation action
         // TODO introduce settle time
-        prepareActions[CameraState::ACTION_FILTER] = false;
+        prepareActions[CAPTURE_ACTION_FILTER] = false;
 
         emit changeFilterPosition(targetFilterID, m_filterPolicy);
         emit prepareState(CAPTURE_CHANGING_FILTER);
     }
-    setInitialized(CameraState::ACTION_FILTER, true);
+    setInitialized(CAPTURE_ACTION_FILTER, true);
 
     if (value == targetFilterID)
-        prepareActions[CameraState::ACTION_FILTER] = true;
+        prepareActions[CAPTURE_ACTION_FILTER] = true;
 
     checkAllActionsReady();
 }
 
 void SequenceJobState::setCurrentCCDTemperature(double currentTemperature)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     // skip if next value should be ignored
-    if (ignoreNextValue[CameraState::ACTION_TEMPERATURE])
+    if (ignoreNextValue[CAPTURE_ACTION_TEMPERATURE])
     {
-        ignoreNextValue[CameraState::ACTION_TEMPERATURE] = false;
+        ignoreNextValue[CAPTURE_ACTION_TEMPERATURE] = false;
         return;
     }
 
-    if (isInitialized(CameraState::ACTION_TEMPERATURE))
+    if (isInitialized(CAPTURE_ACTION_TEMPERATURE))
     {
         if (m_enforceTemperature == false
                 || fabs(targetTemperature - currentTemperature) <= Options::maxTemperatureDiff())
-            prepareActions[CameraState::ACTION_TEMPERATURE] = true;
+            prepareActions[CAPTURE_ACTION_TEMPERATURE] = true;
 
         checkAllActionsReady();
     }
     else
     {
-        setInitialized(CameraState::ACTION_TEMPERATURE, true);
+        setInitialized(CAPTURE_ACTION_TEMPERATURE, true);
         if (m_enforceTemperature == false
                 || fabs(targetTemperature - currentTemperature) <= Options::maxTemperatureDiff())
         {
-            prepareActions[CameraState::ACTION_TEMPERATURE] = true;
+            prepareActions[CAPTURE_ACTION_TEMPERATURE] = true;
             checkAllActionsReady();
         }
         else
@@ -702,25 +714,29 @@ void SequenceJobState::setCurrentCCDTemperature(double currentTemperature)
 
 void SequenceJobState::setCurrentRotatorPositionAngle(double rotatorAngle, IPState state)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     double currentPositionAngle = RotatorUtils::Instance()->calcCameraAngle(rotatorAngle, false);
 
-    if (isInitialized(CameraState::ACTION_ROTATOR))
+    if (isInitialized(CAPTURE_ACTION_ROTATOR))
     {
         // TODO introduce settle time
         // TODO make sure rotator has fully stopped -> see 'align.cpp' captureAndSolve()
         if (fabs(currentPositionAngle - targetPositionAngle) * 60 <= Options::astrometryRotatorThreshold()
                 && state != IPS_BUSY)
-            prepareActions[CameraState::ACTION_ROTATOR] = true;
+            prepareActions[CAPTURE_ACTION_ROTATOR] = true;
 
         checkAllActionsReady();
     }
     else
     {
-        setInitialized(CameraState::ACTION_ROTATOR, true);
+        setInitialized(CAPTURE_ACTION_ROTATOR, true);
         if (fabs(currentPositionAngle - targetPositionAngle) * 60 <= Options::astrometryRotatorThreshold()
                 && state != IPS_BUSY)
         {
-            prepareActions[CameraState::ACTION_ROTATOR] = true;
+            prepareActions[CAPTURE_ACTION_ROTATOR] = true;
             checkAllActionsReady();
         }
         else
@@ -732,13 +748,17 @@ void SequenceJobState::setCurrentRotatorPositionAngle(double rotatorAngle, IPSta
 
 void SequenceJobState::setFocusStatus(FocusState state)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     switch (state)
     {
         case FOCUS_COMPLETE:
             // did we wait for a successful autofocus run?
-            if (prepareActions[CameraState::ACTION_AUTOFOCUS] == false)
+            if (prepareActions[CAPTURE_ACTION_AUTOFOCUS] == false)
             {
-                prepareActions[CameraState::ACTION_AUTOFOCUS] = true;
+                prepareActions[CAPTURE_ACTION_AUTOFOCUS] = true;
                 checkAllActionsReady();
             }
             break;
@@ -755,12 +775,16 @@ void SequenceJobState::setFocusStatus(FocusState state)
 
 void SequenceJobState::updateManualScopeCover(bool closed, bool success, bool light)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     // covering confirmed
     if (success == true)
     {
         if (closed)
             m_CameraState->m_ManualCoverState = light ? CameraState::MANUAL_COVER_CLOSED_LIGHT :
-                    CameraState::MANUAL_COVER_CLOSED_DARK;
+                                                CameraState::MANUAL_COVER_CLOSED_DARK;
         else
             m_CameraState->m_ManualCoverState = CameraState::MANAUL_COVER_OPEN;
         coverQueryState = CAL_CHECK_TASK;
@@ -770,7 +794,7 @@ void SequenceJobState::updateManualScopeCover(bool closed, bool success, bool li
     // cancelled
     else
     {
-        m_CameraState->shutterStatus = CameraState::SHUTTER_UNKNOWN;
+        m_CameraState->shutterStatus = SHUTTER_UNKNOWN;
         coverQueryState = CAL_CHECK_TASK;
         // abort, no further checks
         emit abortCapture();
@@ -779,7 +803,11 @@ void SequenceJobState::updateManualScopeCover(bool closed, bool success, bool li
 
 void SequenceJobState::lightBoxLight(bool on)
 {
-    m_CameraState->setLightBoxLightState(on ? CameraState::CAP_LIGHT_ON : CameraState::CAP_LIGHT_OFF);
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
+    m_CameraState->setLightBoxLightState(on ? CAP_LIGHT_ON : CAP_LIGHT_OFF);
     emit newLog(i18n(on ? "Light box on." : "Light box off."));
     // re-run checks
     checkAllActionsReady();
@@ -787,6 +815,10 @@ void SequenceJobState::lightBoxLight(bool on)
 
 void SequenceJobState::dustCapStateChanged(ISD::DustCap::Status status)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     switch (status)
     {
         case ISD::DustCap::CAP_ERROR:
@@ -803,6 +835,10 @@ void SequenceJobState::dustCapStateChanged(ISD::DustCap::Status status)
 
 void SequenceJobState::scopeStatusChanged(ISD::Mount::Status status)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     // handle wall position
     switch (status)
     {
@@ -840,6 +876,10 @@ void SequenceJobState::domeStatusChanged(ISD::Dome::Status)
 
 void SequenceJobState::flatSyncFocusChanged(bool completed)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     flatSyncStatus = (completed ? FS_COMPLETED : FS_BUSY);
     // re-run checks
     checkAllActionsReady();
@@ -847,10 +887,14 @@ void SequenceJobState::flatSyncFocusChanged(bool completed)
 
 void SequenceJobState::hasShutter(bool present)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     if (present == true)
-        m_CameraState->shutterStatus = CameraState::SHUTTER_YES;
+        m_CameraState->shutterStatus = SHUTTER_YES;
     else
-        m_CameraState->shutterStatus = CameraState::SHUTTER_NO;
+        m_CameraState->shutterStatus = SHUTTER_NO;
 
     // re-run checks
     checkAllActionsReady();
@@ -863,11 +907,15 @@ SequenceJobState::PreparationState SequenceJobState::getPreparationState() const
 
 void SequenceJobState::setFilterStatus(FilterState filterState)
 {
+    // ignore events if preparation is already completed
+    if (preparationCompleted())
+        return;
+
     switch (filterState)
     {
         case FILTER_AUTOFOCUS:
             // we need to wait until focusing has completed
-            prepareActions[CameraState::ACTION_AUTOFOCUS] = false;
+            prepareActions[CAPTURE_ACTION_AUTOFOCUS] = false;
             emit prepareState(CAPTURE_FOCUSING);
             break;
 
