@@ -301,11 +301,11 @@ class SequenceJobState: public QObject
         // ////////////////////////////////////////////////////////////////////
 
         // Mapping PrepareActions --> bool marks whether a certain action is completed (=true) or not (=false)
-        QMap<CameraState::PrepareActions, bool> prepareActions;
+        QMap<CaptureWorkflowActionType, bool> prepareActions;
         // This is a workaround for a specific INDI behaviour. If a INDI property is set, it sends this value
         // back to the clients. If the value does not immediately change to the target value (like e.g. the CCD
         // temperature), the first value after setting a property must be ignored.
-        QMap<CameraState::PrepareActions, bool> ignoreNextValue;
+        QMap<CaptureWorkflowActionType, bool> ignoreNextValue;
 
         // capture frame type (light, flat, dark, bias)
         CCDFrameType m_frameType { FRAME_NONE };
@@ -323,7 +323,7 @@ class SequenceJobState: public QObject
         // status of the focuser synchronisation
         FlatSyncStatus flatSyncStatus { FS_NONE };
         // light source for flat capturing
-        uint32_t m_CalibrationPreAction { ACTION_NONE };
+        uint32_t m_CalibrationPreAction { CAPTURE_PREACTION_NONE };
         // wall coordinates for capturing flats with the wall as light source
         SkyPoint wallCoord;
         // telescope status for flats using the wall position
@@ -343,6 +343,14 @@ class SequenceJobState: public QObject
          */
         bool areActionsReady();
 
+        /**
+         * @brief preparationCompleted helper function for checking, if the preparation has been completed
+         */
+        bool preparationCompleted()
+        {
+            return m_PreparationState == PREP_COMPLETED;
+        }
+
         /**
          * @brief Clear all actions required for preparation
          */
@@ -377,11 +385,11 @@ class SequenceJobState: public QObject
         /**
          * @brief Check if a certain action has already been initialized
          */
-        bool isInitialized(CameraState::PrepareActions action);
+        bool isInitialized(CaptureWorkflowActionType action);
         /**
          * @brief Set a certain action as initialized
          */
-        void setInitialized(CameraState::PrepareActions action, bool init);
+        void setInitialized(CaptureWorkflowActionType action, bool init);
 
         // ////////////////////////////////////////////////////////////////////
         // flats preparation state
