@@ -19,6 +19,7 @@
 #include "ekos/align/align.h"
 #include "ekos/capture/capture.h"
 #include "ekos/capture/cameraprocess.h"
+#include "ekos/focus/focusmodule.h"
 #include "kspaths.h"
 #include "Options.h"
 
@@ -50,7 +51,6 @@ Media::Media(Ekos::Manager * manager, QVector<QSharedPointer<NodeManager>> &node
     connect(this, &Media::newImage, this, [this](const QByteArray & image)
     {
         uploadImage(image);
-        m_TemporaryView.clear();
     });
 }
 
@@ -284,14 +284,13 @@ void Media::sendDarkLibraryData(const QSharedPointer<FITSData> &data)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Media::sendData(const QSharedPointer<FITSData> &data, const QString &uuid)
 {
-    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false)
+    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false || isConnected() == false)
         return;
 
-    m_UUID = uuid;
-
-    m_TemporaryView.reset(new FITSView());
-    m_TemporaryView->loadData(data);
-    QtConcurrent::run(this, &Media::upload, m_TemporaryView);
+    StretchParams params;
+    QImage image;
+    stretch(data, image, params);
+    upload(data, image, params, uuid);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -299,17 +298,12 @@ void Media::sendData(const QSharedPointer<FITSData> &data, const QString &uuid)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Media::sendFile(const QString &filename, const QString &uuid)
 {
-    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false)
+    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false || isConnected() == false)
         return;
 
-    m_UUID = uuid;
-
-    QSharedPointer<FITSView> previewImage(new FITSView());
-    connect(previewImage.get(), &FITSView::loaded, this, [this, previewImage]()
-    {
-        QtConcurrent::run(this, &Media::upload, previewImage);
-    });
-    previewImage->loadFile(filename);
+    QSharedPointer<FITSData> data(new FITSData());
+    data->loadFromFile(filename);
+    QtConcurrent::run(this, &Media::dispatch, data, uuid);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -317,18 +311,64 @@ void Media::sendFile(const QString &filename, const QString &uuid)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Media::sendView(const QSharedPointer<FITSView> &view, const QString &uuid)
 {
-    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false)
+    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false || isConnected() == false)
         return;
 
-    m_UUID = uuid;
-
-    upload(view);
+    upload(view, uuid);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////////
-void Media::upload(const QSharedPointer<FITSView> &view)
+void Media::dispatch(const QSharedPointer<FITSData> &data, const QString &uuid)
+{
+    QSharedPointer<FITSView> previewImage(new FITSView());
+    previewImage->loadData(data);
+    upload(previewImage, uuid);
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Media::stretch(const QSharedPointer<FITSData> &data, QImage &image, StretchParams &params) const
+{
+    double min = 0, max = 0;
+    data->getMinMax(&min, &max);
+    auto width = data->width();
+    auto height = data->height();
+    auto channels = data->channels();
+    auto dataType = data->dataType();
+
+    if (min == max)
+    {
+        image.fill(Qt::white);
+    }
+
+    if (channels == 1)
+    {
+        image = QImage(width, height, QImage::Format_Indexed8);
+
+        image.setColorCount(256);
+        for (int i = 0; i < 256; i++)
+            image.setColor(i, qRgb(i, i, i));
+    }
+    else
+    {
+        image = QImage(width, height, QImage::Format_RGB32);
+    }
+
+    Stretch stretch(width, height, channels, dataType);
+
+    // Compute new auto-stretch params.
+    params = stretch.computeParams(data->getImageBuffer());
+    stretch.setParams(params);
+    stretch.run(data->getImageBuffer(), &image, 1);
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Media::upload(const QSharedPointer<FITSView> &view, const QString &uuid)
 {
     const QString ext = "jpg";
     QByteArray jpegData;
@@ -351,6 +391,7 @@ void Media::upload(const QSharedPointer<FITSView> &view)
 
     // Account for binning
     const double binned_pixel = pixel_size.toDouble() * xbin.toInt();
+
     // Send everything as strings
     QJsonObject metadata =
     {
@@ -364,7 +405,7 @@ void Media::upload(const QSharedPointer<FITSView> &view)
         {"max", imageData->getMax()},
         {"bin", QString("%1x%2").arg(xbin.toString(), ybin.toString())},
         {"bpp", QString::number(imageData->bpp())},
-        {"uuid", m_UUID},
+        {"uuid", uuid},
         {"exposure", exposure.toString()},
         {"focal_length", focal_length.toString()},
         {"aperture", aperture.toString()},
@@ -386,7 +427,7 @@ void Media::upload(const QSharedPointer<FITSView> &view)
     meta = meta.leftJustified(METADATA_PACKET, 0);
     buffer.write(meta);
 
-    auto fastImage = (!Options::ekosLiveHighBandwidth() || m_UUID[0] == "+");
+    auto fastImage = (!Options::ekosLiveHighBandwidth() || uuid[0] == "+");
     auto scaleWidth = fastImage ? HB_IMAGE_WIDTH / 2 : HB_IMAGE_WIDTH;
 
     // For low bandwidth images
@@ -401,11 +442,88 @@ void Media::upload(const QSharedPointer<FITSView> &view)
     emit newImage(jpegData);
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Media::upload(const QSharedPointer<FITSData> &data, const QImage &image, const StretchParams &params,
+                   const QString &uuid)
+{
+    const QString ext = "jpg";
+    QByteArray jpegData;
+    QBuffer buffer(&jpegData);
+    buffer.open(QIODevice::WriteOnly);
+
+    QString resolution = QString("%1x%2").arg(data->width()).arg(data->height());
+    QString sizeBytes = KFormat().formatByteSize(data->size());
+    QVariant xbin(1), ybin(1), exposure(0), focal_length(0), gain(0), pixel_size(0), aperture(0);
+    data->getRecordValue("XBINNING", xbin);
+    data->getRecordValue("YBINNING", ybin);
+    data->getRecordValue("EXPTIME", exposure);
+    data->getRecordValue("GAIN", gain);
+    data->getRecordValue("PIXSIZE1", pixel_size);
+    data->getRecordValue("FOCALLEN", focal_length);
+    data->getRecordValue("APTDIA", aperture);
+
+    // Account for binning
+    const double binned_pixel = pixel_size.toDouble() * xbin.toInt();
+
+    // Send everything as strings
+    QJsonObject metadata =
+    {
+        {"resolution", resolution},
+        {"size", sizeBytes},
+        {"channels", data->channels()},
+        {"mean", data->getAverageMean()},
+        {"median", data->getAverageMedian()},
+        {"stddev", data->getAverageStdDev()},
+        {"min", data->getMin()},
+        {"max", data->getMax()},
+        {"bin", QString("%1x%2").arg(xbin.toString(), ybin.toString())},
+        {"bpp", QString::number(data->bpp())},
+        {"uuid", uuid},
+        {"exposure", exposure.toString()},
+        {"focal_length", focal_length.toString()},
+        {"aperture", aperture.toString()},
+        {"gain", gain.toString()},
+        {"pixel_size", QString::number(binned_pixel, 'f', 4)},
+        {"shadows", params.grey_red.shadows},
+        {"midtones", params.grey_red.midtones},
+        {"highlights", params.grey_red.highlights},
+        {"hasWCS", data->hasWCS()},
+        {"hfr", data->getHFR()},
+        {"ext", ext}
+    };
+
+    // First METADATA_PACKET bytes of the binary data is always allocated
+    // to the metadata
+    // the rest to the image data.
+    QByteArray meta = QJsonDocument(metadata).toJson(QJsonDocument::Compact);
+    meta = meta.leftJustified(METADATA_PACKET, 0);
+    buffer.write(meta);
+
+    auto fastImage = (!Options::ekosLiveHighBandwidth() || uuid[0] == "+");
+    auto scaleWidth = fastImage ? HB_IMAGE_WIDTH / 2 : HB_IMAGE_WIDTH;
+
+    // For low bandwidth images
+    // Except for dark frames +D
+    QImage scaledImage = image.width() > scaleWidth ?
+                         image.scaledToWidth(scaleWidth, fastImage ? Qt::FastTransformation : Qt::SmoothTransformation) :
+                         image;
+    scaledImage.save(&buffer, ext.toLatin1().constData(), HB_IMAGE_QUALITY);
+
+    buffer.close();
+
+    emit newImage(jpegData);
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Media::sendUpdatedFrame(const QSharedPointer<FITSView> &view)
 {
+    if (isConnected() == false)
+        return;
+
     QString ext = "jpg";
     QByteArray jpegData;
     QBuffer buffer(&jpegData);
@@ -503,7 +621,10 @@ void Media::sendUpdatedFrame(const QSharedPointer<FITSView> &view)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Media::sendVideoFrame(const QSharedPointer<QImage> &frame)
 {
-    if (Options::ekosLiveImageTransfer() == false || m_sendBlobs == false || !frame)
+    if (isConnected() == false ||
+            Options::ekosLiveImageTransfer() == false ||
+            m_sendBlobs == false ||
+            !frame)
         return;
 
     int32_t width = Options::ekosLiveHighBandwidth() ? HB_VIDEO_WIDTH : HB_VIDEO_WIDTH / 2;
@@ -545,7 +666,6 @@ void Media::sendVideoFrame(const QSharedPointer<QImage> &frame)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Media::registerCameras()
 {
-    static const QRegularExpression re("[-{}]");
     for(auto &oneDevice : INDIListener::devices())
     {
         auto camera = oneDevice->getCamera();
@@ -564,10 +684,7 @@ void Media::registerCameras()
     process->disconnect(this);
     connect(process, &Ekos::CameraProcess::newView, this, [this](const QSharedPointer<FITSView> &view)
     {
-        // Set UUID for each view
-        QString uuid = QUuid::createUuid().toString();
-        uuid = uuid.remove(re);
-        sendView(view, uuid);
+        sendView(view, view->imageData()->objectName());
     });
 }
 
@@ -605,7 +722,7 @@ void Media::sendModuleFrame(const QSharedPointer<FITSView> &view)
 
     if (qobject_cast<Ekos::Align*>(sender()) == m_Manager->alignModule())
         sendView(view, "+A");
-    else if (qobject_cast<Ekos::Focus*>(sender()) == m_Manager->focusModule())
+    else if (qobject_cast<Ekos::FocusModule*>(sender()) == m_Manager->focusModule())
         sendView(view, "+F");
     else if (qobject_cast<Ekos::Guide*>(sender()) == m_Manager->guideModule())
         sendView(view, "+G");
