@@ -52,7 +52,6 @@ class Focus : public QWidget, public Ui::Focus
         Q_OBJECT
         Q_CLASSINFO("D-Bus Interface", "org.kde.kstars.Ekos.Focus")
         Q_PROPERTY(Ekos::FocusState status READ status NOTIFY newStatus)
-        Q_PROPERTY(QStringList logText READ logText NOTIFY newLog)
         Q_PROPERTY(QString opticalTrain READ opticalTrain WRITE setOpticalTrain)
         Q_PROPERTY(QString camera READ camera)
         Q_PROPERTY(QString focuser READ focuser)
@@ -64,9 +63,10 @@ class Focus : public QWidget, public Ui::Focus
         // AdaptiveFocus and FocusAdvisor are friend classes so they can access methods in Focus
         friend class AdaptiveFocus;
         friend class FocusAdvisor;
+        friend class FocusModule;
 
     public:
-        Focus();
+        Focus(int id = 0);
         ~Focus();
 
         typedef enum { FOCUS_NONE, FOCUS_IN, FOCUS_OUT } Direction;
@@ -219,11 +219,11 @@ class Focus : public QWidget, public Ui::Focus
         void selectImageMask();
 
         /**
-             * @brief addTemperatureSource Add temperature source to the list of available sources.
-             * @param newSource Device with temperature reporting capability
-             * @return True if added successfully, false if duplicate or failed to add.
-             */
-        bool addTemperatureSource(const QSharedPointer<ISD::GenericDevice> &device);
+         * @brief updateTemperatureSources Update list of available temperature sources.
+         * @param temperatureSources Devices with temperature reporting capability
+         * @return True if updated successfully
+         */
+        void updateTemperatureSources(const QList<QSharedPointer<ISD::GenericDevice>> &temperatureSources);
 
         /**
          * @brief removeDevice Remove device from Focus module
@@ -238,16 +238,6 @@ class Focus : public QWidget, public Ui::Focus
         void setupFilterManager();
         void connectFilterManager();
 
-        Q_SCRIPTABLE void clearLog();
-        QStringList logText()
-        {
-            return m_LogText;
-        }
-        QString getLogText()
-        {
-            return m_LogText.join("\n");
-        }
-
         // Settings
         QVariantMap getAllSettings() const;
         void setAllSettings(const QVariantMap &settings);
@@ -402,10 +392,9 @@ class Focus : public QWidget, public Ui::Focus
              * @param status If true, the focus process finished successfully. Otherwise, it failed.
              */
         //void setAutoFocusResult(bool status);
-
-        // Logging methods - one for INFO messages to the kstars log, and one for a CSV auto-focus log
-        void appendLogText(const QString &);
-        void appendFocusLogText(const QString &);
+        // Logging
+        void appendLogText(const QString &logtext);
+        void appendFocusLogText(const QString &text);
 
         // Adjust focuser offset, relative or absolute
         void adjustFocusOffset(int value, bool useAbsoluteOffset);
@@ -489,15 +478,18 @@ class Focus : public QWidget, public Ui::Focus
 
     signals:
         void newLog(const QString &text);
-        void newStatus(Ekos::FocusState state);
-        void newHFR(double hfr, int position, bool inAutofocus);
-        void newFocusTemperatureDelta(double delta, double absTemperature);
+        void newFocusLog(const QString &text);
+        void newStatus(Ekos::FocusState state, const QString &trainname);
+        void newHFR(double hfr, int position, bool inAutofocus, const QString &trainname);
+        void newFocusTemperatureDelta(double delta, double absTemperature, const QString &trainname);
+        void inSequenceAF(bool requested, const QString &trainname);
 
         void absolutePositionChanged(int value);
         void focusPositionAdjusted();
-        void focusAdaptiveComplete(bool success);
+        void focusAdaptiveComplete(bool success, const QString &trainname);
 
         void trainChanged();
+        void focuserChanged(int id, bool isValid);
 
         void suspendGuiding();
         void resumeGuiding();
@@ -933,6 +925,7 @@ class Focus : public QWidget, public Ui::Focus
 
         /// Focuser device needed for focus operation
         ISD::Focuser *m_Focuser { nullptr };
+        int m_focuserId;
         /// CCD device needed for focus operation
         ISD::Camera *m_Camera { nullptr };
         /// Optional device filter
@@ -1005,6 +998,8 @@ class Focus : public QWidget, public Ui::Focus
         int currentPosition { 0 };
         /// Motion state of the absolute focuser
         IPState currentPositionState {IPS_IDLE};
+        /// flag if position or state has changed (to avoid too much logging)
+        bool logPositionAndState {true};
         /// What was our position before we started the focus process?
         int initialFocuserAbsPosition { -1 };
         /// Pulse duration in ms for relative focusers that only support timers, or the number of ticks in a relative or absolute focuser
@@ -1089,12 +1084,6 @@ class Focus : public QWidget, public Ui::Focus
         // Rerun flag indicating a rerun due to AF failing
         bool m_AFRerun = false;
 
-        /// Autofocus log file info.
-        QStringList m_LogText;
-        QFile m_FocusLogFile;
-        QString m_FocusLogFileName;
-        bool m_FocusLogEnabled { false };
-
         ITextVectorProperty *filterName { nullptr };
         INumberVectorProperty *filterSlot { nullptr };
 
@@ -1124,12 +1113,18 @@ class Focus : public QWidget, public Ui::Focus
 
         /// State
         FocusState m_state { Ekos::FOCUS_IDLE };
+        FocusState m_pendingState { Ekos::FOCUS_IDLE };
         FocusState state() const
         {
             return m_state;
         }
         void setState(FocusState newState);
 
+        bool isBusy()
+        {
+            return m_state == FOCUS_WAITING || m_state == FOCUS_PROGRESS || m_state == FOCUS_FRAMING || m_state == FOCUS_CHANGING_FILTER;
+        }
+
         /// CCD Chip frame settings
         QMap<ISD::CameraChip *, QVariantMap> frameSettings;
 
