@@ -197,7 +197,7 @@ void FocusHFRVPlot::drawHFRPlot(double currentValue, int pulseDuration)
 
     double minVal = currentDisplayValue / 2.5;
     if (m_displayValue.size() > 0)
-        minVal = std::max(0.0, std::min(minValue, *std::min_element(m_displayValue.begin(), m_displayValue.end())));
+        minVal = std::min(minValue, *std::min_element(m_displayValue.begin(), m_displayValue.end()));
 
     // True for the position-based algorithms and those that simulate position.
     if (m_showPositions)
@@ -253,6 +253,13 @@ void FocusHFRVPlot::setTitle(const QString &title, bool plot)
     if (plot) replot();
 }
 
+QString FocusHFRVPlot::title() const
+{
+    if (plotTitle)
+        return plotTitle->text();
+    return QString();
+}
+
 void FocusHFRVPlot::finalUpdates(const QString &title, bool plot)
 {
     // Update a previously set title without having to redraw everything
@@ -339,7 +346,6 @@ void FocusHFRVPlot::drawCFZ(double solutionPosition, double solutionValue, int c
         CFZ->left->setType(QCPItemPosition::ptPlotCoords);
         CFZ->right->setType(QCPItemPosition::ptPlotCoords);
 
-        double displayValue = getDisplayValue(solutionValue);
         double y;
         if (m_Minimum)
             y = (7 * minValue - maxValue) / 6;
