@@ -8,6 +8,7 @@
 
 #include <math.h>
 #include "ekos_guide_debug.h"
+#include "Options.h"
 
 // Finds the star in sortedStars that's closest to x,y and within maxDistance pixels.
 // Returns the index of the closest star in  sortedStars, or -1 if none satisfies the criteria.
@@ -240,7 +241,7 @@ void StarCorrespondence::makeOffsets(const QVector<Offsets> &offsets, QVector<Of
 
 // We create an imaginary star from the ones we did find.
 Edge StarCorrespondence::inventStarPosition(const QList<Edge> &stars, const QVector<int> &starMap,
-        QVector<Offsets> offsets, Offsets offset) const
+        const QVector<Offsets> &offsets, const Offsets &offset) const
 {
     Edge inventedStar;
     inventedStar.invalidate();
@@ -324,7 +325,7 @@ Edge StarCorrespondence::find(const QList<Edge> &stars, double maxDistance,
     Edge foundStar;
     foundStar.invalidate();
     if (!initialized)  return foundStar;
-    int numFound, numNotFound;
+    int numFound = 0, numNotFound = 0;
 
     // findClosestStar needs an input with stars sorted by their x.
     // Do this outside of the loops.
@@ -332,11 +333,20 @@ Edge StarCorrespondence::find(const QList<Edge> &stars, double maxDistance,
     QVector<int> sortedToOriginal;
     sortByX(stars, &sortedStars, &sortedToOriginal);
 
-    QVector<int> sortedStarMap;
-    int bestStarIndex = findInternal(sortedStars, maxDistance, &sortedStarMap, guideStarIndex,
-                                     guideStarOffsets, &numFound, &numNotFound, minFraction);
+    const bool alwaysInvent = Options::alwaysInventGuideStar() &&
+                              stars.size() >= minFraction * guideStarOffsets.size();
+    if (!alwaysInvent && Options::alwaysInventGuideStar())
+        qCDebug(KSTARS_EKOS_GUIDE)
+                << QString("Could not use AlwaysInvent--too few stars: %1 < %2 * %3 (%4)").arg(stars.size())
+                .arg(minFraction, 0, 'f', 2).arg(guideStarOffsets.size()).arg(minFraction * guideStarOffsets.size(), 0, 'f', 1);
+    const bool canInvent = allowMissingGuideStar && stars.size() >= minFraction * guideStarOffsets.size();
 
-    if (bestStarIndex > -1)
+    QVector<int> sortedStarMap;
+    int bestStarIndex =
+        alwaysInvent ? -1 : findInternal(sortedStars, maxDistance, &sortedStarMap, guideStarIndex,
+                                         guideStarOffsets, &numFound, &numNotFound, minFraction);
+
+    if (!alwaysInvent && bestStarIndex > -1)
     {
         // Convert back to the unsorted index value.
         bestStarIndex = sortedToOriginal[bestStarIndex];
@@ -348,21 +358,35 @@ Edge StarCorrespondence::find(const QList<Edge> &stars, double maxDistance,
                 << numFound << numNotFound;
         m_NumReferencesFound = numFound;
     }
-    else if (allowMissingGuideStar && bestStarIndex == -1 &&
-             stars.size() >= minFraction * guideStarOffsets.size())
+    else if (alwaysInvent || canInvent)
     {
-        qCDebug(KSTARS_EKOS_GUIDE)
-                << "Trying in invent. StarCorrespondence did NOT find guideStar. Found/not"
-                << numFound << numNotFound << "minFraction" << minFraction << "maxDistance" << maxDistance;
-        // If we didn't find a good solution, perhaps the guide star was not detected.
-        // See if we can get a reasonable solution from the other stars.
+        // If we didn't find a good solution in findInternal() above (with alwaysInvent false), perhaps
+        // the guide star was not detected. We try to get around that by getting an estimate of its position
+        // from many reference stars. If alwaysInvent is true, we always wind up here, as that estimate is
+        // likely more robust anyway than consistently finding the one guide star.
+        if (!alwaysInvent)
+            qCDebug(KSTARS_EKOS_GUIDE)
+                    << "Trying to invent. StarCorrespondence did NOT find guideStar. Found/not"
+                    << numFound << numNotFound << "minFraction" << minFraction << "maxDistance" << maxDistance;
+        else
+            qCDebug(KSTARS_EKOS_GUIDE)
+                    << "Using AlwaysInvent. #stars" << stars.size() << "minFraction" << minFraction << "maxDistance" << maxDistance;
+
         int bestNumFound = 0;
         int bestNumNotFound = 0;
         Edge bestInvented;
         bestInvented.invalidate();
+        // For each reference star, pretend it was the guide star by using makeOffsets() to convert the
+        // original guide-star's offsets to new offsets relative to that reference star.
+        // Then, using findInternal(), map the detected stars to the reference stars.
+        // If we were successful in doing that (i.e. the reference star was actually detected)
+        // then we should know the positions of all (detected) reference stars.
+        // We then use inventStarPosition() to make an "invented guide star position" by reversing the
+        // offsets and translating each found ref star position back to a guide-star position and finding
+        // the median position of those. We only need to do this for one (actually detected) reference star.
         for (int gStarIndex = 0; gStarIndex < guideStarOffsets.size(); gStarIndex++)
         {
-            if (gStarIndex == guideStarIndex)
+            if (!alwaysInvent && gStarIndex == guideStarIndex)
                 continue;
             QVector<Offsets> gStarOffsets;
             makeOffsets(guideStarOffsets, &gStarOffsets, gStarIndex);
@@ -382,8 +406,9 @@ Edge StarCorrespondence::find(const QList<Edge> &stars, double maxDistance,
                 bestNumNotFound = numNotFound;
                 sortedStarMap = newStarMap;
 
-                if (numNotFound <= 1)
-                    // We can't do better than this.
+                // If enough of the references were found to reliably estimate the guide-star position
+                // then we can break out of the loop. Nothing special about 7, just a guess.
+                if (numNotFound <= 1 || bestNumFound >= 7)
                     break;
             }
         }
@@ -395,6 +420,10 @@ Edge StarCorrespondence::find(const QList<Edge> &stars, double maxDistance,
                     << "StarCorrespondence found guideStar (invented) at "
                     << bestInvented.x << bestInvented.y << "found/not" << bestNumFound << bestNumNotFound;
             m_NumReferencesFound = bestNumFound;
+
+            if (alwaysInvent && adapt)
+                adaptOffsets(stars, *starMap, bestInvented.x, bestInvented.y);
+
             return bestInvented;
         }
         else qCDebug(KSTARS_EKOS_GUIDE) << "StarCorrespondence could not invent guideStar.";
@@ -402,7 +431,7 @@ Edge StarCorrespondence::find(const QList<Edge> &stars, double maxDistance,
     else qCDebug(KSTARS_EKOS_GUIDE) << "StarCorrespondence could not find guideStar.";
 
     if (adapt && (bestStarIndex != -1))
-        adaptOffsets(stars, *starMap);
+        adaptOffsets(stars, *starMap, foundStar.x, foundStar.y);
     return foundStar;
 }
 
@@ -420,7 +449,7 @@ void StarCorrespondence::initializeAdaptation()
     originalGuideStarOffsets = guideStarOffsets;
 }
 
-void StarCorrespondence::adaptOffsets(const QList<Edge> &stars, const QVector<int> &starMap)
+void StarCorrespondence::adaptOffsets(const QList<Edge> &stars, const QVector<int> &starMap, double x, double y)
 {
     const int numStars = stars.size();
     if (starMap.size() != numStars)
@@ -428,21 +457,6 @@ void StarCorrespondence::adaptOffsets(const QList<Edge> &stars, const QVector<in
         qCDebug(KSTARS_EKOS_GUIDE) << "Adapt error: StarMap size != stars.size()" << starMap.size() << numStars;
         return;
     }
-    // guideStar will be the index in stars corresponding to the reference guide star.
-    int guideStar = -1;
-    for (int i = 0; i < numStars; ++i)
-    {
-        if (starMap[i] == guideStarIndex)
-        {
-            guideStar = i;
-            break;
-        }
-    }
-    if (guideStar < 0)
-    {
-        qCDebug(KSTARS_EKOS_GUIDE) << "Adapt error: no guide star in map";
-        return;
-    }
 
     for (int i = 0; i < numStars; ++i)
     {
@@ -459,8 +473,8 @@ void StarCorrespondence::adaptOffsets(const QList<Edge> &stars, const QVector<in
         }
         // Adapt the x and y offsets using the following IIR filter:
         // output[t] = alpha * offset[t] + (1-alpha) * output[t-1]
-        const double xOffset = stars[i].x - stars[guideStar].x;
-        const double yOffset = stars[i].y - stars[guideStar].y;
+        const double xOffset = stars[i].x - x;
+        const double yOffset = stars[i].y - y;
         const double currentXOffset = guideStarOffsets[refIndex].x;
         const double currentYOffset = guideStarOffsets[refIndex].y;
         const double newXOffset = alpha * xOffset + (1 - alpha) * currentXOffset;
