@@ -1086,6 +1086,8 @@ void ProfileEditor::executeScriptEditor()
         currentDrivers << oneCombo->currentText();
     currentDrivers.removeAll("--");
     currentDrivers.removeAll("");
+    for (auto &oneDriver : ui->remoteDrivers->text().split(","))
+        currentDrivers << oneDriver;
     currentDrivers.sort();
     ProfileScriptDialog dialog(currentDrivers, pi->scripts, this);
     dialog.exec();
