@@ -41,6 +41,7 @@ class GreedyScheduler;
 class SchedulerProcess;
 class SchedulerModuleState;
 class SequenceEditor;
+class SchedulerAltitudeGraph;
 
 /**
  * @brief The Ekos scheduler is a simple scheduler class to orchestrate automated multi object observation jobs.
@@ -148,7 +149,11 @@ public:
         /**
          * @brief addJob Add a new job from form values
          */
-        void addJob(SchedulerJob *job = nullptr);
+        Q_INVOKABLE void addJob(SchedulerJob *job = nullptr);
+        /**
+         * @brief addJob Add a new job from form values
+         */
+        Q_INVOKABLE void updateJob(int index = -1);
 
         /**
          * @brief createJob Create a new job from form values.
@@ -285,7 +290,9 @@ protected slots:
              * @brief editJob Edit an observation job
              * @param i index model in queue table
              */
-        void loadJob(QModelIndex i);
+        Q_INVOKABLE void loadJob(QModelIndex i);
+
+        Q_INVOKABLE bool modifyJob(int index = -1);
 
         /**
          * @brief updateSchedulerURL Update scheduler URL after succesful loading a new file.
@@ -300,7 +307,7 @@ protected slots:
         /**
              * @brief setJobManipulation Enable or disable job manipulation buttons.
              */
-        void setJobManipulation(bool can_reorder, bool can_delete);
+        void setJobManipulation(bool can_reorder, bool can_delete, bool is_lead);
 
         /**
          * @brief set all GUI fields to the values of the given scheduler job
@@ -320,7 +327,7 @@ protected slots:
         /**
          * @brief clearJobTable delete all rows in the job table
          */
-        void clearJobTable();
+        Q_INVOKABLE void clearJobTable();
 
         /**
          * @brief clearLog Clears log entry
@@ -375,9 +382,9 @@ protected slots:
          * @param clearQueue Clear the queue before loading, or append ESL contents to queue.
          * @param filename If not empty, this file will be used instead of poping up a dialog.
          */
-        bool load(bool clearQueue, const QString &filename = QString());
+        Q_INVOKABLE bool load(bool clearQueue, const QString &filename = QString());
 
-        void resetJobEdit();
+        Q_INVOKABLE void resetJobEdit();
 
         /**
          * @brief updateNightTime update the Twilight restriction with the argument job properties.
@@ -478,6 +485,11 @@ private:
          */
         bool syncControl(const QVariantMap &settings, const QString &key, QWidget * widget);
 
+        // ////////////////////////////////////////////////////////////////////
+        // Optical Train handling
+        // ////////////////////////////////////////////////////////////////////
+        void refreshOpticalTrain();
+
         /**
          * @brief checkJobInputComplete Check if all inputs are filled such that a new job could be added.
          */
@@ -500,6 +512,7 @@ private:
         // react upon changes of EKOS and INDI state
         void ekosStateChanged(EkosState state);
         void indiStateChanged(INDIState state);
+        void indiCommunicationStatusChanged(CommunicationStatus status);
 
         // react upon state changes
         void startupStateChanged(StartupState state);
@@ -542,5 +555,9 @@ private:
         QTimer m_JobUpdateDebounce;
         QVariantMap m_Settings;
         QVariantMap m_GlobalSettings;
+
+        // Altitude Graph
+        QPointer<SchedulerAltitudeGraph> m_altitudeGraph;
+        void handleAltitudeGraph(int index);
 };
 }
