@@ -14,7 +14,6 @@
 #include "scheduler.h"
 #include "schedulermodulestate.h"
 #include "schedulerutils.h"
-#include "ksalmanac.h"
 #include "ksmoon.h"
 
 #include <knotification.h>
@@ -99,7 +98,7 @@ QString SchedulerJob::jobStartupConditionString(StartupCondition condition) cons
         case START_ASAP:
             return "ASAP";
         case START_AT:
-            return QString("AT %1").arg(getFileStartupTime().toString("MM/dd hh:mm"));
+            return QString("AT %1").arg(getStartAtTime().toString("MM/dd hh:mm"));
     }
     return QString("????");
 }
@@ -115,7 +114,7 @@ QString SchedulerJob::jobCompletionConditionString(CompletionCondition condition
         case FINISH_LOOP:
             return "LOOP";
         case FINISH_AT:
-            return QString("AT %1").arg(getCompletionTime().toString("MM/dd hh:mm"));
+            return QString("AT %1").arg(getFinishAtTime().toString("MM/dd hh:mm"));
     }
     return QString("????");
 }
@@ -142,6 +141,8 @@ void SchedulerJob::setGroup(const QString &value)
     group = value;
 }
 
+
+
 void SchedulerJob::setCompletedIterations(int value)
 {
     completedIterations = value;
@@ -179,7 +180,7 @@ void SchedulerJob::setStartupCondition(const StartupCondition &value)
     SchedulerModuleState::calculateDawnDusk(startupTime, nextDawn, nextDusk);
 }
 
-void SchedulerJob::setStartupTime(const QDateTime &value)
+void SchedulerJob::setStartupTime(const QDateTime &value, bool refreshDawnDusk)
 {
     startupTime = value;
 
@@ -190,13 +191,18 @@ void SchedulerJob::setStartupTime(const QDateTime &value)
         startupCondition = fileStartupCondition;
 
     // Refresh altitude - invalid date/time is taken care of when rendering
-    altitudeAtStartup = SchedulerUtils::findAltitude(targetCoords, startupTime, &settingAtStartup);
+    altitudeAtStartup = SchedulerUtils::findAltitude(getTargetCoords(), startupTime, &settingAtStartup);
 
     /* Refresh estimated time - which update job cells */
     setEstimatedTime(estimatedTime);
 
+    /* propagate it to all follower jobs, but avoid unnecessary dawn/dusk refresh */
+    for (auto follower : followerJobs())
+        follower->setStartupTime(value, false);
+
     /* Refresh dawn and dusk for startup date */
-    SchedulerModuleState::calculateDawnDusk(startupTime, nextDawn, nextDusk);
+    if (refreshDawnDusk)
+        SchedulerModuleState::calculateDawnDusk(startupTime, nextDawn, nextDusk);
 }
 
 void SchedulerJob::setSequenceFile(const QUrl &value)
@@ -217,7 +223,7 @@ void SchedulerJob::setMinAltitude(const double &value)
 bool SchedulerJob::hasAltitudeConstraint() const
 {
     return hasMinAltitude() ||
-           (enforceArtificialHorizon && (getHorizon() != nullptr) && getHorizon()->altitudeConstraintsExist()) ||
+           (getEnforceArtificialHorizon() && (getHorizon() != nullptr) && getHorizon()->altitudeConstraintsExist()) ||
            (Options::enableAltitudeLimits() &&
             (Options::minimumAltLimit() > 0 ||
              Options::maximumAltLimit() < 90));
@@ -233,42 +239,54 @@ void SchedulerJob::setEnforceWeather(bool value)
     enforceWeather = value;
 }
 
-void SchedulerJob::setGreedyCompletionTime(const QDateTime &value)
+void SchedulerJob::setStopTime(const QDateTime &value)
 {
-    greedyCompletionTime = value;
+    stopTime = value;
+
+    // update altitude and setting at stop time
+    if (value.isValid())
+    {
+        altitudeAtStop = SchedulerUtils::findAltitude(getTargetCoords(), stopTime, &settingAtStop);
+
+        /* propagate it to all follower jobs, but avoid unnecessary dawn/dusk refresh */
+        for (auto follower : followerJobs())
+        {
+            // if the lead job completes earlier as the follower would do, set its completion time to the lead job's
+            if (follower->getStartupTime().isValid() && value.isValid()
+                    && (follower->getEstimatedTime() < 0 || follower->getEstimatedTime() > getEstimatedTime()))
+                follower->setEstimatedTime(getEstimatedTime());
+        }
+    }
 }
 
-void SchedulerJob::setCompletionTime(const QDateTime &value)
+void SchedulerJob::setFinishAtTime(const QDateTime &value)
 {
-    setGreedyCompletionTime(QDateTime());
+    setStopTime(QDateTime());
 
     /* If completion time is valid, automatically switch condition to FINISH_AT */
     if (value.isValid())
     {
         setCompletionCondition(FINISH_AT);
-        completionTime = value;
-        altitudeAtCompletion = SchedulerUtils::findAltitude(targetCoords, completionTime, &settingAtCompletion);
+        finishAtTime = value;
         setEstimatedTime(-1);
     }
     /* If completion time is invalid, and job is looping, keep completion time undefined */
     else if (FINISH_LOOP == completionCondition)
     {
-        completionTime = QDateTime();
-        altitudeAtCompletion = SchedulerUtils::findAltitude(targetCoords, completionTime, &settingAtCompletion);
+        finishAtTime = QDateTime();
         setEstimatedTime(-1);
     }
     /* If completion time is invalid, deduce completion from startup and duration */
     else if (startupTime.isValid())
     {
-        completionTime = startupTime.addSecs(estimatedTime);
-        altitudeAtCompletion = SchedulerUtils::findAltitude(targetCoords, completionTime, &settingAtCompletion);
+        finishAtTime = startupTime.addSecs(estimatedTime);
     }
     /* Else just refresh estimated time - which update job cells */
     else setEstimatedTime(estimatedTime);
 
 
     /* Invariants */
-    Q_ASSERT_X(completionTime.isValid() ?
+    Q_ASSERT_X(finishAtTime.isValid() ?
                (FINISH_AT == completionCondition || FINISH_REPEAT == completionCondition || FINISH_SEQUENCE == completionCondition) :
                FINISH_LOOP == completionCondition,
                __FUNCTION__, "Valid completion time implies job is FINISH_AT/REPEAT/SEQUENCE, else job is FINISH_LOOP.");
@@ -282,7 +300,7 @@ void SchedulerJob::setCompletionCondition(const CompletionCondition &value)
     switch (completionCondition)
     {
         case FINISH_LOOP:
-            setCompletionTime(QDateTime());
+            setFinishAtTime(QDateTime());
         /* Fall through */
         case FINISH_AT:
             if (0 < getRepeatsRequired())
@@ -309,35 +327,80 @@ void SchedulerJob::setStepPipeline(const StepPipeline &value)
     stepPipeline = value;
 }
 
-void SchedulerJob::setState(const SchedulerJobStatus &value)
+void SchedulerJob::setState(const SchedulerJobStatus &value, bool force)
 {
     state = value;
     stateTime = getLocalTime();
 
-    /* FIXME: move this to Scheduler, SchedulerJob is mostly a model */
-    if (SCHEDJOB_ERROR == state)
+    switch (state)
     {
-        lastErrorTime = getLocalTime();
-        KNotification::event(QLatin1String("EkosSchedulerJobFail"), i18n("Ekos job failed (%1)", getName()));
+        case SCHEDJOB_ERROR:
+            /* FIXME: move this to Scheduler, SchedulerJob is mostly a model */
+            lastErrorTime = getLocalTime();
+            KNotification::event(QLatin1String("EkosSchedulerJobFail"), i18n("Ekos job failed (%1)", getName()));
+            break;
+        case SCHEDJOB_INVALID:
+        case SCHEDJOB_IDLE:
+            /* If job becomes invalid or idle, automatically reset its startup characteristics, and force its duration to be reestimated */
+            setStartupCondition(fileStartupCondition);
+            setStartupTime(startAtTime);
+            setEstimatedTime(-1);
+            break;
+        case SCHEDJOB_ABORTED:
+            /* If job is aborted, automatically reset its startup characteristics */
+            lastAbortTime = getLocalTime();
+            setStartupCondition(fileStartupCondition);
+            /* setStartupTime(fileStartupTime); */
+            break;
+        default:
+            /* do nothing */
+            break;
     }
+    // propagate it to the follower jobs
+    if (isLead())
+        setFollowerState(value, force);
+}
 
-    /* If job becomes invalid or idle, automatically reset its startup characteristics, and force its duration to be reestimated */
-    if (SCHEDJOB_INVALID == value || SCHEDJOB_IDLE == value)
+void SchedulerJob::setFollowerState(const SchedulerJobStatus &value, bool force)
+{
+    for (auto follower : followerJobs())
     {
-        setStartupCondition(fileStartupCondition);
-        setStartupTime(fileStartupTime);
-        setEstimatedTime(-1);
-    }
+        // do not propagate the state if the job is running
+        if (follower->getState() == SCHEDJOB_BUSY && force == false)
+            continue;
 
-    /* If job is aborted, automatically reset its startup characteristics */
-    if (SCHEDJOB_ABORTED == value)
-    {
-        lastAbortTime = getLocalTime();
-        setStartupCondition(fileStartupCondition);
-        /* setStartupTime(fileStartupTime); */
+        switch (value)
+        {
+            case SCHEDJOB_EVALUATION:
+            case SCHEDJOB_IDLE:
+                // always forward evaluation and startup, since only the lead job is part of the scheduling
+                follower->setState(value);
+                break;
+            case SCHEDJOB_SCHEDULED:
+                // if the lead job is scheduled, the follower job will be scheduled unless it is complete
+                follower->setState(follower->getCompletionCondition() == FINISH_LOOP
+                                   || follower->getEstimatedTime() > 0 ? value : SCHEDJOB_COMPLETE);
+                break;
+            default:
+                // do NOT forward the state, each follower job needs to be started individually
+                if (force)
+                    follower->setState(value);
+                break;
+        }
     }
 }
 
+void SchedulerJob::updateSharedFollowerAttributes()
+{
+    if (isLead())
+        for (auto follower : followerJobs())
+        {
+            follower->setStartupTime(getStartupTime(), false);
+            follower->setStartAtTime(getStartAtTime());
+            follower->setFollowerState(getState(), true);
+        }
+}
+
 
 void SchedulerJob::setSequenceCount(const int count)
 {
@@ -360,9 +423,9 @@ void SchedulerJob::setFileStartupCondition(const StartupCondition &value)
     fileStartupCondition = value;
 }
 
-void SchedulerJob::setFileStartupTime(const QDateTime &value)
+void SchedulerJob::setStartAtTime(const QDateTime &value)
 {
-    fileStartupTime = value;
+    startAtTime = value;
 }
 
 void SchedulerJob::setEstimatedTime(const int64_t &value)
@@ -378,14 +441,12 @@ void SchedulerJob::setEstimatedTime(const int64_t &value)
     /* If startup and completion times are fixed, estimated time cannot change - disregard the argument */
     if (START_ASAP != fileStartupCondition && FINISH_AT == completionCondition)
     {
-        estimatedTime = startupTime.secsTo(completionTime);
+        estimatedTime = startupTime.secsTo(finishAtTime);
     }
     /* If completion time isn't fixed, estimated time adjusts completion time */
     else if (FINISH_AT != completionCondition && FINISH_LOOP != completionCondition)
     {
         estimatedTime = value;
-        completionTime = startupTime.addSecs(value);
-        altitudeAtCompletion = SchedulerUtils::findAltitude(targetCoords, completionTime, &settingAtCompletion);
     }
     /* Else estimated time is simply stored as is - covers FINISH_LOOP from setCompletionTime */
     else estimatedTime = value;
@@ -471,12 +532,12 @@ void SchedulerJob::reset()
     lastErrorTime = QDateTime();
     estimatedTime = -1;
     startupCondition = fileStartupCondition;
-    startupTime = fileStartupCondition == START_AT ? fileStartupTime : QDateTime();
+    startupTime = fileStartupCondition == START_AT ? startAtTime : QDateTime();
 
     /* Refresh dawn and dusk for startup date */
     SchedulerModuleState::calculateDawnDusk(startupTime, nextDawn, nextDusk);
 
-    greedyCompletionTime = QDateTime();
+    stopTime = QDateTime();
     stopReason.clear();
 
     /* No change to culmination offset */
@@ -511,6 +572,9 @@ bool SchedulerJob::decreasingAltitudeOrder(SchedulerJob const *job1, SchedulerJo
 
 bool SchedulerJob::satisfiesAltitudeConstraint(double azimuth, double altitude, QString *altitudeReason) const
 {
+    if (m_LeadJob != nullptr)
+        return m_LeadJob->satisfiesAltitudeConstraint(azimuth, altitude, altitudeReason);
+
     // Check the mount's altitude constraints.
     if (Options::enableAltitudeLimits() &&
             (altitude < Options::minimumAltLimit() ||
@@ -661,6 +725,9 @@ QDateTime SchedulerJob::calculateNextTime(QDateTime const &when, bool checkIfCon
 bool SchedulerJob::runsDuringAstronomicalNightTime(const QDateTime &time,
         QDateTime *nextPossibleSuccess) const
 {
+    if (m_LeadJob != nullptr)
+        return m_LeadJob->runsDuringAstronomicalNightTime(time, nextPossibleSuccess);
+
     // We call this very frequently in the Greedy Algorithm, and the calls
     // below are expensive. Almost all the calls are redundent (e.g. if it's not nighttime
     // now, it's not nighttime in 10 minutes). So, cache the answer and return it if the next
@@ -702,6 +769,9 @@ bool SchedulerJob::runsDuringAstronomicalNightTime(const QDateTime &time,
 bool SchedulerJob::runsDuringAstronomicalNightTimeInternal(const QDateTime &time, QDateTime *minDawnDusk,
         QDateTime *nextPossibleSuccess) const
 {
+    if (m_LeadJob != nullptr)
+        return m_LeadJob->runsDuringAstronomicalNightTimeInternal(time, minDawnDusk, nextPossibleSuccess);
+
     QDateTime t;
     QDateTime nDawn = nextDawn, nDusk = nextDusk;
     if (time.isValid())
@@ -819,17 +889,17 @@ QDateTime SchedulerJob::getNextPossibleStartTime(const QDateTime &when, int incr
 
     if (!runningJob && START_AT == getFileStartupCondition())
     {
-        int secondsFromNow = ltWhen.secsTo(getFileStartupTime());
+        int secondsFromNow = ltWhen.secsTo(getStartAtTime());
         if (secondsFromNow < -500)
             // We missed it.
             return QDateTime();
-        ltWhen = secondsFromNow > 0 ? getFileStartupTime() : ltWhen;
+        ltWhen = secondsFromNow > 0 ? getStartAtTime() : ltWhen;
     }
 
     // Can't start if we're past the finish time.
     if (getCompletionCondition() == FINISH_AT)
     {
-        const QDateTime &t = getCompletionTime();
+        const QDateTime &t = getFinishAtTime();
         if (t.isValid() && t < ltWhen)
             return QDateTime(); // return an invalid time.
     }
@@ -864,7 +934,7 @@ QDateTime SchedulerJob::getNextEndTime(const QDateTime &start, int increment, QS
 
     if (START_AT == getFileStartupCondition())
     {
-        if (getFileStartupTime().secsTo(ltStart) < -120)
+        if (getStartAtTime().secsTo(ltStart) < -120)
         {
             // if the file startup time is in the future, then end now.
             // This case probably wouldn't happen in the running code.
@@ -877,17 +947,17 @@ QDateTime SchedulerJob::getNextEndTime(const QDateTime &start, int increment, QS
     // Can't start if we're past the finish time.
     if (getCompletionCondition() == FINISH_AT)
     {
-        const QDateTime &t = getCompletionTime();
+        const QDateTime &t = getFinishAtTime();
         if (t.isValid() && t < ltStart)
         {
             if (reason) *reason = "end-at time";
             return QDateTime(); // return an invalid time.
         }
         auto result = calculateNextTime(ltStart, false, increment, reason, false, until);
-        if (!result.isValid() || result.secsTo(getCompletionTime()) < 0)
+        if (!result.isValid() || result.secsTo(getFinishAtTime()) < 0)
         {
             if (reason) *reason = "end-at time";
-            return getCompletionTime();
+            return getFinishAtTime();
         }
         else return result;
     }
@@ -992,8 +1062,8 @@ QJsonObject SchedulerJob::toJson() const
     {
         {"name", name},
         {"pa", m_PositionAngle},
-        {"targetRA", targetCoords.ra0().Hours()},
-        {"targetDEC", targetCoords.dec0().Degrees()},
+        {"targetRA", getTargetCoords().ra0().Hours()},
+        {"targetDEC", getTargetCoords().dec0().Degrees()},
         {"state", state},
         {"stage", stage},
         {"sequenceCount", sequenceCount},
@@ -1004,9 +1074,13 @@ QJsonObject SchedulerJob::toJson() const
         {"repeatsRemaining", repeatsRemaining},
         {"inSequenceFocus", inSequenceFocus},
         {"startupTime", startupTime.isValid() ? startupTime.toString() : "--"},
-        {"completionTime", completionTime.isValid() ? completionTime.toString() : "--"},
+        {"completionTime", finishAtTime.isValid() ? finishAtTime.toString() : "--"},
         {"altitude", alt},
+        {"altitudeFormatted", m_AltitudeFormatted},
+        {"startupFormatted", m_StartupFormatted},
+        {"endFormatted", m_EndFormatted},
         {"sequence", sequenceFile.toString() },
     };
 }
+
 } // Ekos namespace
