@@ -59,7 +59,10 @@ class SchedulerJob
         /** @{ */
         SkyPoint const &getTargetCoords() const
         {
-            return targetCoords;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getTargetCoords();
+            else
+                return targetCoords;
         }
         void setTargetCoords(const dms &ra, const dms &dec, double djd);
         /** @} */
@@ -83,7 +86,10 @@ class SchedulerJob
         /** @{ */
         QUrl getFITSFile() const
         {
-            return fitsFile;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getFITSFile();
+            else
+                return fitsFile;
         }
         void setFITSFile(const QUrl &value);
         /** @} */
@@ -92,7 +98,10 @@ class SchedulerJob
         /** @{ */
         double getMinAltitude() const
         {
-            return minAltitude;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getMinAltitude();
+            else
+                return minAltitude;
         }
         void setMinAltitude(const double &value);
         /** @} */
@@ -101,7 +110,7 @@ class SchedulerJob
         /** @{ */
         bool hasMinAltitude() const
         {
-            return UNDEFINED_ALTITUDE < minAltitude;
+            return UNDEFINED_ALTITUDE < getMinAltitude();
         }
         static constexpr int UNDEFINED_ALTITUDE = -90;
         /** @} */
@@ -115,7 +124,10 @@ class SchedulerJob
         /** @{ */
         double getMinMoonSeparation() const
         {
-            return minMoonSeparation;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getMinMoonSeparation();
+            else
+                return minMoonSeparation;
         }
         void setMinMoonSeparation(const double &value);
         /** @} */
@@ -124,7 +136,10 @@ class SchedulerJob
         /** @{ */
         bool getEnforceWeather() const
         {
-            return enforceWeather;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getEnforceWeather();
+            else
+                return enforceWeather;
         }
         void setEnforceWeather(bool value);
         /** @} */
@@ -133,7 +148,10 @@ class SchedulerJob
         /** @{ */
         StepPipeline getStepPipeline() const
         {
-            return stepPipeline;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getStepPipeline();
+            else
+                return stepPipeline;
         }
         void setStepPipeline(const StepPipeline &value);
         /** @} */
@@ -142,7 +160,10 @@ class SchedulerJob
         /** @{ */
         StartupCondition getStartupCondition() const
         {
-            return startupCondition;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getStartupCondition();
+            else
+                return startupCondition;
         }
         void setStartupCondition(const StartupCondition &value);
         /** @} */
@@ -160,18 +181,24 @@ class SchedulerJob
         /** @{ */
         StartupCondition getFileStartupCondition() const
         {
-            return fileStartupCondition;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getFileStartupCondition();
+            else
+                return fileStartupCondition;
         }
         void setFileStartupCondition(const StartupCondition &value);
         /** @} */
 
         /** @brief Original time at which the job must start, as entered by the user. */
         /** @{ */
-        QDateTime getFileStartupTime() const
+        QDateTime getStartAtTime() const
         {
-            return fileStartupTime;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getStartAtTime();
+            else
+                return startAtTime;
         }
-        void setFileStartupTime(const QDateTime &value);
+        void setStartAtTime(const QDateTime &value);
         /** @} */
 
         /** @brief Whether this job requires re-focus while running its capture sequence. */
@@ -187,7 +214,10 @@ class SchedulerJob
         /** @{ */
         bool getEnforceTwilight() const
         {
-            return enforceTwilight;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getEnforceTwilight();
+            else
+                return enforceTwilight;
         }
         void setEnforceTwilight(bool value);
         /** @} */
@@ -196,7 +226,10 @@ class SchedulerJob
         /** @{ */
         bool getEnforceArtificialHorizon() const
         {
-            return enforceArtificialHorizon;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getEnforceArtificialHorizon();
+            else
+                return enforceArtificialHorizon;
         }
         void setEnforceArtificialHorizon(bool value);
         /** @} */
@@ -205,20 +238,50 @@ class SchedulerJob
         /** @{ */
         QString getName() const
         {
-            return name;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getName();
+            else
+                return name;
         }
         void setName(const QString &value);
         /** @} */
 
+        /** @brief Flag if the scheduler job is a lead job with its own target or if it is a follower job to another lead job. */
+        /** @{ */
+        bool isLead() const
+        {
+            return m_isLead;
+        }
+        void setIsLead(bool value)
+        {
+            m_isLead = value;
+        }
+        /** @} */
+
         /** @brief Group the scheduler job belongs to. */
         /** @{ */
         QString getGroup() const
         {
-            return group;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getGroup();
+            else
+                return group;
         }
         void setGroup(const QString &value);
         /** @} */
 
+        /** @brief Optical train the scheduler job will be using. */
+        /** @{ */
+        QString getOpticalTrain() const
+        {
+            return opticalTrain;
+        }
+        void setOpticalTrain(const QString &value)
+        {
+            opticalTrain = value;
+        }
+        /** @} */
+
         /** @brief Iteration the scheduler job has achieved. This only makes sense for jobs that repeat. */
         /** @{ */
         int getCompletedIterations() const
@@ -239,6 +302,14 @@ class SchedulerJob
         {
             return state;
         }
+
+        /**
+         * @brief isStopped helper function for idle or aborted state
+         */
+        bool isStopped() const
+        {
+            return (state == SCHEDJOB_IDLE || state == SCHEDJOB_ABORTED);
+        }
         QDateTime getStateTime() const
         {
             return stateTime;
@@ -251,7 +322,14 @@ class SchedulerJob
         {
             return lastErrorTime;
         }
-        void setState(const SchedulerJobStatus &value);
+        void setState(const SchedulerJobStatus &value, bool force = false);
+
+        void setFollowerState(const SchedulerJobStatus &value, bool force);
+
+        /**
+         * @brief Update the attributes of all followers that are shared with the lead job
+         */
+        void updateSharedFollowerAttributes();
         /** @} */
 
         /** @brief Current stage of the scheduler job. */
@@ -287,18 +365,18 @@ class SchedulerJob
         {
             return startupTime;
         }
-        void setStartupTime(const QDateTime &value);
+        void setStartupTime(const QDateTime &value, bool refreshDawnDusk = true);
         /** @} */
 
-        /** @brief Time after which the job is considered complete. */
+        /** @brief Time after which the job is considered to finish. */
         /** @{ */
-        QDateTime getCompletionTime() const
+        QDateTime getFinishAtTime() const
         {
-            return completionTime;
+            return finishAtTime;
         }
-        QDateTime getGreedyCompletionTime() const
+        QDateTime getStopTime() const
         {
-            return greedyCompletionTime;
+            return stopTime;
         }
         const QString &getStopReason() const
         {
@@ -308,9 +386,9 @@ class SchedulerJob
         {
             stopReason = reason;
         }
-        void setCompletionTime(const QDateTime &value);
+        void setFinishAtTime(const QDateTime &value);
         /** @} */
-        void setGreedyCompletionTime(const QDateTime &value);
+        void setStopTime(const QDateTime &value);
 
         /** @brief Estimation of the time the job will take to process. */
         /** @{ */
@@ -336,7 +414,10 @@ class SchedulerJob
         /** @{ */
         int64_t getEstimatedStartupTime() const
         {
-            return estimatedStartupTime;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getEstimatedStartupTime();
+            else
+                return estimatedStartupTime;
         }
         void setEstimatedStartupTime(const int64_t &value)
         {
@@ -427,7 +508,7 @@ class SchedulerJob
          */
         bool isDuplicateOf(SchedulerJob const *a_job) const
         {
-            return this != a_job && name == a_job->name && sequenceFile == a_job->sequenceFile;
+            return this != a_job && name == a_job->getName() && sequenceFile == a_job->sequenceFile;
         }
 
         /** @brief Compare ::SchedulerJob instances based on altitude and movement in sky at startup time.
@@ -470,7 +551,10 @@ class SchedulerJob
              */
         QDateTime getDawnAstronomicalTwilight() const
         {
-            return nextDawn;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getDawnAstronomicalTwilight();
+            else
+                return nextDawn;
         };
 
         /**
@@ -480,7 +564,10 @@ class SchedulerJob
              */
         QDateTime getDuskAstronomicalTwilight() const
         {
-            return nextDusk;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getDuskAstronomicalTwilight();
+            else
+                return nextDusk;
         };
 
         /**
@@ -520,19 +607,66 @@ class SchedulerJob
         }
         double getAltitudeAtStartup() const
         {
-            return altitudeAtStartup;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->getAltitudeAtStartup();
+            else
+                return altitudeAtStartup;
         }
-        double getAltitudeAtCompletion() const
+        double getAltitudeAtStop() const
         {
-            return altitudeAtCompletion;
+            return altitudeAtStop;
         }
         bool isSettingAtStartup() const
         {
-            return settingAtStartup;
+            if (m_LeadJob != nullptr)
+                return m_LeadJob->isSettingAtStartup();
+            else
+                return settingAtStartup;
         }
-        bool isSettingAtCompletion() const
+        bool isSettingAtStop() const
         {
-            return settingAtCompletion;
+            return settingAtStop;
+        }
+
+        SchedulerJob *leadJob() const
+        {
+            return m_LeadJob;
+        }
+        void setLeadJob(SchedulerJob *newLeadJob)
+        {
+            m_LeadJob = newLeadJob;
+        }
+
+        QList<SchedulerJob *> &followerJobs()
+        {
+            return m_followerJobs;
+        }
+
+        void setStartupFormatted(const QString &value)
+        {
+            m_StartupFormatted = value;
+        }
+        const QString &startupFormatted() const
+        {
+            return m_StartupFormatted;
+        }
+
+        void setEndFormatted(const QString &value)
+        {
+            m_EndFormatted = value;
+        }
+        const QString &endFormatted() const
+        {
+            return m_EndFormatted;
+        }
+
+        void setAltitudeFormatted(const QString &value)
+        {
+            m_AltitudeFormatted = value;
+        }
+        const QString &altitudeFormatted() const
+        {
+            return m_AltitudeFormatted;
         }
 
 private:
@@ -564,13 +698,19 @@ private:
         /** @} */
 
         QString name;
+        bool m_isLead { true };
         QString group;
+        QString opticalTrain;
         int completedIterations { 0 };
         SkyPoint targetCoords;
         double m_PositionAngle { -1 };
         SchedulerJobStatus state { SCHEDJOB_IDLE };
         SchedulerJobStage stage { SCHEDSTAGE_IDLE };
 
+        // leader / follower relationship
+        SchedulerJob *m_LeadJob { nullptr };
+        QList <SchedulerJob *> m_followerJobs;
+
         // The time that the job stage was set.
         // Used by the Greedy Algorithm to decide when to run JOB_ABORTED jobs again.
         QDateTime stateTime;
@@ -584,20 +724,24 @@ private:
         int sequenceCount { 0 };
         int completedCount { 0 };
 
-        QDateTime fileStartupTime;
+        // Defined startup time, used for the StartupCondition START_AT.
+        QDateTime startAtTime;
+        // Startup time calculated by the scheduler.
         QDateTime startupTime;
-        QDateTime completionTime;
-        // An alternative completionTime field used by the greedy scheduler algorithm.
-        QDateTime greedyCompletionTime;
+        // Completion constraint when the job must finish, used for the CompletionCondition FINISH_AT.
+        QDateTime finishAtTime;
+        // Next time when the scheduler will stop the job, either because its
+        // completed, its constraints aren't met or another job has higher priority.
+        QDateTime stopTime;
         // The reason this job is stopping/will-be stopped.
         QString stopReason;
 
         /* @internal Caches to optimize cell rendering. */
         /* @{ */
         double altitudeAtStartup { 0 };
-        double altitudeAtCompletion { 0 };
+        double altitudeAtStop { 0 };
         bool settingAtStartup { false };
-        bool settingAtCompletion { false };
+        bool settingAtStop { false };
         /* @} */
 
         QUrl sequenceFile;
@@ -626,10 +770,12 @@ private:
 
         QString dateTimeDisplayFormat;
 
+        QString m_StartupFormatted, m_EndFormatted, m_AltitudeFormatted;
+
         bool lightFramesRequired { false };
         bool m_CalibrationMountPark {false};
 
-        QMap<QString, uint16_t> capturedFramesMap;
+        CapturedFramesMap capturedFramesMap;
 
         /// Pointer to Moon object
         KSMoon *moon { nullptr };
