@@ -7,6 +7,7 @@
 #pragma once
 
 #include "schedulertypes.h"
+#include "schedulerjob.h"
 #include "ekos/auxiliary/modulelogger.h"
 #include "ekos/align/align.h"
 #include "ekos/auxiliary/solverutils.h"
@@ -21,7 +22,6 @@
 namespace Ekos
 {
 
-class SchedulerJob;
 class GreedyScheduler;
 class SchedulerModuleState;
 
@@ -163,6 +163,8 @@ public:
      */
     Q_SCRIPTABLE Q_NOREPLY void startCapture(bool restart = false);
 
+    void startSingleCapture(SchedulerJob *job, bool restart = false);
+
     /**
      * @brief updateCompletedJobsCount For each scheduler job, examine sequence job storage and count captures.
      * @param forced forces recounting captures unconditionally if true, else only IDLE, EVALUATION or new jobs are examined.
@@ -631,8 +633,9 @@ private slots:
      * @brief checkAlignment Handle one sequence image completion. This is used now only to run alignment check
      * to ensure it does not deviation from current scheduler job target.
      * @param metadata Metadata for image including filename, exposure, filter, hfr..etc.
+     * @param trainname name of the optical train that has captured the image
      */
-    void checkAlignment(const QVariantMap &metadata);
+    void checkAlignment(const QVariantMap &metadata, const QString &trainname);
 
     /**
      * @brief solverDone Process solver solution after it is done.
@@ -670,8 +673,8 @@ private slots:
     // ////////////////////////////////////////////////////////////////////
     void setAlignStatus(Ekos::AlignState status);
     void setGuideStatus(Ekos::GuideState status);
-    void setCaptureStatus(Ekos::CaptureState status, const QString &devicename);
-    void setFocusStatus(Ekos::FocusState status);
+    void setCaptureStatus(Ekos::CaptureState status, const QString &trainname);
+    void setFocusStatus(Ekos::FocusState status, const QString &trainname);
     void setMountStatus(ISD::Mount::Status status);
     void setWeatherStatus(ISD::Weather::Status status);
 
@@ -690,6 +693,10 @@ private:
     QProcess m_scriptProcess;
     // solver for alignment checks
     QSharedPointer<SolverUtils> m_Solver;
+
+    // mapping train name --> scheduler job
+    QMap<QString, SchedulerJob*> m_activeJobs;
+
     // ////////////////////////////////////////////////////////////////////
     // DBUS interfaces
     // ////////////////////////////////////////////////////////////////////
@@ -809,5 +816,11 @@ private:
     // Prints all the relative state variables set during an iteration. For debugging.
     void printStates(const QString &label);
 
+    /**
+     * @brief Abort capturing
+     * @param train train name, if empty abort the master job, otherwise abort this job's capture
+     * @param followersOnly if true and train name is empty, do not abort the lead, but all its followers
+     */
+    void stopCapturing(QString train = "", bool followersOnly = false);
 };
 } // Ekos namespace
