@@ -31,8 +31,8 @@ typedef enum
     FITS_GAUSSIAN,
     FITS_ROTATE_CW,
     FITS_ROTATE_CCW,
-    FITS_FLIP_H,
-    FITS_FLIP_V,
+    FITS_MOUNT_FLIP_H,
+    FITS_MOUNT_FLIP_V,
     FITS_AUTO,
     FITS_LINEAR,
     FITS_LOG,
@@ -42,7 +42,7 @@ typedef enum
 
 typedef enum { ZOOM_FIT_WINDOW, ZOOM_KEEP_LEVEL, ZOOM_FULL } FITSZoom;
 
-typedef enum { HFR_AVERAGE, HFR_MEDIAN, HFR_HIGH, HFR_MAX } HFRType;
+typedef enum { HFR_AVERAGE, HFR_MEDIAN, HFR_HIGH, HFR_MAX, HFR_ADJ_AVERAGE } HFRType;
 
 typedef enum { ALGORITHM_GRADIENT, ALGORITHM_CENTROID, ALGORITHM_THRESHOLD, ALGORITHM_SEP, ALGORITHM_BAHTINOV } StarAlgorithm;
 
