@@ -145,7 +145,7 @@ class GenericDevice : public GDInterface
         virtual void processMessage(int messageID) override;
 
         virtual const QString &getDeviceName() const;
-        virtual DriverInfo *getDriverInfo() const
+        virtual const QSharedPointer<DriverInfo> &getDriverInfo() const
         {
             return m_DriverInfo;
         }
@@ -229,8 +229,8 @@ class GenericDevice : public GDInterface
 
     protected:
         void createDeviceInit();
-        void updateTime();
-        void updateLocation();
+        void updateTime(const QString &iso8601 = QString(), const QString &utcOffset = QString());
+        void updateLocation(double longitude = -1, double latitude = -1, double elevation = -1);
         /**
          * @brief generateDevices Generate concrete devices based on DRIVER_INTERFACE
          * @return True if at least one device is generated, false otherwise.
@@ -291,7 +291,7 @@ class GenericDevice : public GDInterface
         bool m_Connected { false };
         bool m_Ready {false};
         QString m_Name;
-        DriverInfo *m_DriverInfo { nullptr };
+        QSharedPointer<DriverInfo> m_DriverInfo;
         DeviceInfo *m_DeviceInfo { nullptr };
         INDI::BaseDevice m_BaseDevice;
         ClientManager *m_ClientManager { nullptr };
