@@ -158,6 +158,10 @@ class KStars : public KXmlGuiWindow
         const QSharedPointer<FITSViewer> &genericFITSViewer();
         const QSharedPointer<FITSViewer> &createFITSViewer();
         void clearAllViewers();
+        const QList<QSharedPointer<FITSViewer>> &getFITSViewers() const
+        {
+            return m_FITSViewers;
+        }
 #endif
 
         /** Add an item to the color-scheme action manu
@@ -605,6 +609,9 @@ class KStars : public KXmlGuiWindow
         /** action slot: toggle whether kstars clock is running or not */
         void slotToggleTimer();
 
+        /** realtime kstars clock was enabled */
+        void slotRealTimeToogled(bool checked);
+
         /** action slot: advance one step forward in time */
         void slotStepForward();
 
