@@ -1,19 +1,8 @@
-/***************************************************************************
-                       eclipsetool.h  -  K Desktop Planetarium
-                             -------------------
-    begin                : Tue 18/09/2018
-    copyright            : (C) 2018 Valentin Boettcher
-    email                : valentin@boettcher.cf
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Valentin Boettcher <valentin@boettcher.cf>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 #include <QFrame>
