@@ -31,6 +31,8 @@
 #include <QTextStream>
 #include <QFileDialog>
 #include <QStandardPaths>
+#include <QTemporaryFile>
+#include <QProcess>
 #include <QDebug>
 
 #include <sys/stat.h>
@@ -78,11 +80,7 @@ void OptionsTreeView::resizeColumns()
             {
                 child->setExpanded(true);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
                 int w = qfm.horizontalAdvance(child->text(icol)) + 4;
-#else
-                int w = qfm.width(child->text(icol)) + 4;
-#endif
 
                 if (icol == 0)
                 {
